package org.bedework.deployment;
import net.fortuna.ical4j.data.CalendarBuilder;
import net.fortuna.ical4j.data.CalendarParserImpl;
import net.fortuna.ical4j.data.UnfoldingReader;
import net.fortuna.ical4j.model.Calendar;
import net.fortuna.ical4j.model.Component;
import net.fortuna.ical4j.model.ComponentList;
import net.fortuna.ical4j.model.TimeZone;
import net.fortuna.ical4j.model.component.VTimeZone;
import net.fortuna.ical4j.util.TimeZones;

import java.io.File;
import java.io.FileReader;
import java.text.DateFormat;
import java.text.SimpleDateFormat;

/**
 *
 */

/**
 * @author douglm
 *
 */
public class TestTimezones {

  private static void setSystemProperties() throws Throwable {
    System.setProperty("ical4j.unfolding.relaxed", "true");
    System.setProperty("ical4j.parsing.relaxed", "true");
    System.setProperty("ical4j.compatibility.outlook", "true");
  }

  private static java.util.TimeZone utctz = TimeZone.getTimeZone(TimeZones.UTC_ID);

  private static class Dt {
    String dt;
    boolean daylight;

    Dt(String dt, boolean daylight) {
      this.dt = dt;
      this.daylight = daylight;
    }
  }
  private static Dt[] dates;

  /**
   * @param args first arg timezone file - second arg count of dates to skip
   */
  public static void main(String[] args) {
    try {
      initDates();

      File tzfile = new File(args[0]);
      FileReader frdr = new FileReader(tzfile);

      int skip = Integer.parseInt(args[1]);

      setSystemProperties();
      CalendarBuilder bldr = new CalendarBuilder(new CalendarParserImpl());

      //return fromIcal(cal, bldr.build(new UnfoldingReader(rdr)));
      Calendar cal = bldr.build(new UnfoldingReader(frdr, true));

      ComponentList clist = cal.getComponents();

      VTimeZone vtz = (VTimeZone)clist.getComponent(Component.VTIMEZONE);
      TimeZone tz = new TimeZone(vtz);

      for (int i = 0; i < dates.length; i++) {
        if (i >= skip) {
          Dt test = dates[i];
          testit(test.dt, tz, test.daylight);
        }
      }
    } catch (Throwable t) {
      t.printStackTrace();
    }
  }

  private static void testit(String dt, TimeZone tz,
                             boolean expectDaylight) throws Throwable {
    DateFormat formatTd  = new SimpleDateFormat("yyyyMMdd'T'HHmmss");
    formatTd.setTimeZone(tz);

    java.util.Date date = formatTd.parse(dt);
    String tztime = formatTd.format(date);

    String warn = "";

    if (expectDaylight != tz.inDaylightTime(date)) {
      warn = "  ******************* expected daylight=" + expectDaylight;
    }
    formatTd.setTimeZone(utctz);
    String utc = formatTd.format(date);
    System.out.println("local: " + tztime + " utc=" + utc + warn);
  }

  private static void initDates() {
    dates = new Dt[] {
        // (    new Dt..200\d10\d\dT\d{6}...)(true)

        // (    new Dt..200\d10\d\dT\d{6}...)(true)

        new Dt("20030821T203000", true),
        new Dt("20030902T150000", true),
       /* new Dt("20030904T130000", true),
        new Dt("20030905T103000", true),
        new Dt("20030904T150000", true),
        new Dt("20030910T110000", true),
        new Dt("20030917T140000", true),
        new Dt("20030910T140000", true),
        new Dt("20030924T140000", true),
        new Dt("20031001T120000", true),
        new Dt("20031008T140000", true),
        new Dt("20030904T193000", true),
        new Dt("20030917T160000", true),
        new Dt("20030903T200000", true),
        new Dt("20030917T200000", true),
        new Dt("20031001T200000", true),
        new Dt("20031008T200000", true),
        new Dt("20031022T200000", true),
        new Dt("20031027T200000", true),
        new Dt("20031112T200000", false),
        new Dt("20031119T200000", false),
        new Dt("20031121T200000", false),
        new Dt("20031105T200000", false),
        new Dt("20030910T090000", true),
        new Dt("20031002T090000", true),
        new Dt("20030913T090000", true),
        new Dt("20030924T170000", true),
        new Dt("20031001T170000", true),
        new Dt("20031115T090000", false),
        new Dt("20030916T110000", true),
        new Dt("20030910T110000", true),
        new Dt("20030911T160000", true),
        new Dt("20030917T090000", true),
        new Dt("20030919T113000", true),
        new Dt("20030908T160000", true),
        new Dt("20030922T160000", true),
        new Dt("20031010T190000", true),
        new Dt("20031008T100000", true),
        new Dt("20030915T193000", true),
        new Dt("20030916T160000", true),
        new Dt("20030917T170000", true),
        new Dt("20030918T200000", true),
        new Dt("20030918T140000", true),
        new Dt("20030919T103000", true),
        new Dt("20031008T110000", true),
        new Dt("20030919T113500", true),
        new Dt("20030919T160000", true),
        new Dt("20030919T120000", true),
        new Dt("20031001T150000", true),
        new Dt("20030924T180000", true),
        new Dt("20031022T134500", true),
        new Dt("20031021T080000", true),
        new Dt("20031023T090000", true),
        new Dt("20030925T150000", true),
        new Dt("20031006T093000", true),
        new Dt("20030923T160000", true),
        new Dt("20030924T160000", true),
        new Dt("20030930T200000", true),
        new Dt("20031003T200000", true),
        new Dt("20031010T200000", true),
        new Dt("20031112T200000", false),
        new Dt("20031022T200000", true),
        new Dt("20031029T200000", true),
        new Dt("20030927T100000", true),
        new Dt("20030924T153000", true),
        new Dt("20030926T103000", true),
        new Dt("20031001T170000", true),
        new Dt("20031025T110000", true),
        new Dt("20031002T200000", true),
        new Dt("20031004T210000", true),
        new Dt("20031025T130000", true),
        new Dt("20031002T193000", true),
        new Dt("20031001T100000", true),
        new Dt("20031001T160000", true),
        new Dt("20031008T170000", true),
        new Dt("20031003T103000", true),
        new Dt("20030930T160000", true),
        new Dt("20031107T100000", false),
        new Dt("20031122T190000", false),
        new Dt("20031006T160000", true),
        new Dt("20031004T130000", true),
        new Dt("20031010T160000", true),
        new Dt("20031011T140000", true),
        new Dt("20031017T160000", true),
        new Dt("20031018T140000", true),
        new Dt("20031024T150000", true),
        new Dt("20031025T130000", true),
        new Dt("20031029T160000", true),
        new Dt("20031003T160000", true),
        new Dt("20031004T140000", true),
        new Dt("20031007T153000", true),
        new Dt("20031011T090000", true),
        new Dt("20031003T190000", true),
        new Dt("20031015T190000", true),
        new Dt("20031024T180000", true),
        new Dt("20031025T160000", true),
        new Dt("20031028T180000", true),
        new Dt("20031010T160000", true),
        new Dt("20031011T140000", true),
        new Dt("20031004T120000", true),
        new Dt("20031018T110000", true),
        new Dt("20031025T110000", true),
        new Dt("20031108T110000", false),
        new Dt("20031115T110000", false),
        new Dt("20031011T130000", true),
        new Dt("20031025T130000", true),
        new Dt("20031101T130000", false),
        new Dt("20031108T130000", false),
        new Dt("20031115T130000", false),
        new Dt("20031004T150000", true),
        new Dt("20031006T190000", true),
        new Dt("20031010T160000", true),
        new Dt("20031011T140000", true),
        new Dt("20031014T190000", true),
        new Dt("20031018T150000", true),
        new Dt("20031024T160000", true),
        new Dt("20031025T140000", true),
        new Dt("20031101T140000", false),
        new Dt("20031012T090000", true),
        new Dt("20031004T170000", true),
        new Dt("20031011T190000", true),
        new Dt("20031017T190000", true),
        new Dt("20031025T190000", true),
        new Dt("20031101T190000", false),
        new Dt("20031107T190000", false),
        new Dt("20031108T190000", false),
        new Dt("20031114T190000", false),
        new Dt("20031115T190000", false),
        new Dt("20031121T190000", false),
        new Dt("20031122T190000", false),
        new Dt("20031128T190000", false),
        new Dt("20031129T190000", false),
        new Dt("20031205T190000", false),
        new Dt("20031206T190000", false),
        new Dt("20040102T190000", false),
        new Dt("20040103T190000", false),
        new Dt("20040109T190000", false),
        new Dt("20040110T190000", false),
        new Dt("20040116T190000", false),
        new Dt("20040117T190000", false),
        new Dt("20040124T190000", false),
        new Dt("20040130T190000", false),
        new Dt("20040131T190000", false),
        new Dt("20040206T190000", false),
        new Dt("20040207T120000", false),
        new Dt("20040207T190000", false),
        new Dt("20040213T190000", false),
        new Dt("20040214T190000", false),
        new Dt("20040220T190000", false),
        new Dt("20040221T190000", false),
        new Dt("20040227T190000", false),
        new Dt("20040228T190000", false),
        new Dt("20031228T160000", false),
        new Dt("20031228T190000", false),
        new Dt("20031229T160000", false),
        new Dt("20031229T190000", false),
        new Dt("20031015T113000", true),
        new Dt("20031107T150000", false),
        new Dt("20031025T160000", true),
        new Dt("20031101T190000", false),
        new Dt("20031115T190000", false),
        new Dt("20031110T180000", false),
        new Dt("20031025T200000", true),
        new Dt("20031102T200000", false),
        new Dt("20031102T200000", false),
        new Dt("20031024T200000", true),
        new Dt("20031008T160000", true),
        new Dt("20031007T153000", true),
        new Dt("20031024T200000", true),
        new Dt("20031008T190000", true),
        new Dt("20031019T181500", true),
        new Dt("20031116T181500", false),
        new Dt("20031011T190000", true),
        new Dt("20031017T190000", true),
        new Dt("20031018T190000", true),
        new Dt("20031024T190000", true),
        new Dt("20031025T190000", true),
        new Dt("20031031T193000", true),
        new Dt("20031101T190000", false),
        new Dt("20031107T190000", false),
        new Dt("20031108T190000", false),
        new Dt("20031114T190000", false),
        new Dt("20031121T190000", false),
        new Dt("20031122T190000", false),
        new Dt("20031205T190000", false),
        new Dt("20031206T190000", false),
        new Dt("20031101T220000", false),
        new Dt("20031009T190000", true),
        new Dt("20031014T113000", true),
        new Dt("20031009T120000", true),
        new Dt("20031024T120000", true),
        new Dt("20031115T120000", false),
        new Dt("20031128T120000", false),
        new Dt("20031008T160000", true),
        new Dt("20031010T180000", true),
        new Dt("20031015T180000", true),
        new Dt("20031018T120000", true),
        new Dt("20031108T120000", false),
        new Dt("20031206T120000", false),
        new Dt("20031207T120000", false),
        new Dt("20031010T120000", true),
        new Dt("20031016T160000", true),
        new Dt("20031015T160000", true),
        new Dt("20031017T153000", true),
        new Dt("20031016T130000", true),
        new Dt("20031018T200000", true),
        new Dt("20031030T160000", true),
        new Dt("20031107T200000", false),
        new Dt("20031108T200000", false),
        new Dt("20031109T020000", false),
        new Dt("20031024T133000", true),
        new Dt("20031113T200000", false),
        new Dt("20031114T200000", false),
        new Dt("20031115T200000", false),
        new Dt("20040206T200000", false),
        new Dt("20040207T200000", false),
        new Dt("20040213T200000", false),
        new Dt("20040214T200000", false),
        new Dt("20040208T020000", false),
        new Dt("20031024T160000", true),
        new Dt("20031025T130000", true),
        new Dt("20031025T140000", true),
        new Dt("20031025T143000", true),
        new Dt("20031025T143000", true),
        new Dt("20031025T170000", true),
        new Dt("20031025T162000", true),
        new Dt("20031025T172000", true),
        new Dt("20031025T170000", true),
        new Dt("20031025T180000", true),
        new Dt("20031025T140000", true),
        new Dt("20031025T151500", true),
        new Dt("20031022T120000", true),
        new Dt("20031025T161500", true),
        new Dt("20031025T130000", true),
        new Dt("20031020T160000", true),
        new Dt("20031023T160000", true),
        new Dt("20031029T160000", true),
        new Dt("20031022T160000", true),
        new Dt("20031023T160000", true),
        new Dt("20031021T153000", true),
        new Dt("20031021T160000", true),
        new Dt("20031021T160000", true),
        new Dt("20031027T160000", true),
        new Dt("20031028T160000", true),
        new Dt("20031030T193000", true),
        new Dt("20031104T153000", false),
        new Dt("20031104T160000", false),
        new Dt("20031113T120000", false),
        new Dt("20031110T160000", false),
        new Dt("20031110T193000", false),
        new Dt("20031117T160000", false),
        new Dt("20031118T160000", false),
        new Dt("20031024T200000", true),
        new Dt("20031025T200000", true),
        new Dt("20031027T190000", true),
        new Dt("20031107T200000", false),
        new Dt("20031114T200000", false),
        new Dt("20031115T200000", false),
        new Dt("20031115T120000", false),
        new Dt("20031028T080000", true),
        new Dt("20031024T103000", true),
        new Dt("20031028T160000", true),
        new Dt("20031026T140000", true),
        new Dt("20031023T120000", true),
        new Dt("20031024T183000", true),
        new Dt("20031114T120000", false),
        new Dt("20031112T193000", false),
        new Dt("20031103T103000", false),
        new Dt("20031104T110000", false),
        new Dt("20031104T160000", false),
        new Dt("20031105T110000", false),
        new Dt("20031105T160000", false),
        new Dt("20031106T160000", false),
        new Dt("20031106T110000", false),
        new Dt("20031107T110000", false),
        new Dt("20031026T110000", true),
        new Dt("20031029T160000", true),
        new Dt("20031107T190000", false),
        new Dt("20031108T093000", false),
        new Dt("20031029T100000", true),
        new Dt("20031028T190000", true),
        new Dt("20031029T160000", true),
        new Dt("20031029T160000", true),
        new Dt("20031028T153000", true),
        new Dt("20031031T103000", true),
        new Dt("20031029T180000", true),
        new Dt("20031122T070000", false),
        new Dt("20031030T070000", true),
        new Dt("20031115T200000", false),
        new Dt("20031104T083000", false),
        new Dt("20031105T083000", false),
        new Dt("20031112T193000", false),
        new Dt("20031029T130000", true),
        new Dt("20031103T160000", false),
        new Dt("20031104T180000", false),
        new Dt("20040713T113000", true),
        new Dt("20031106T193000", false),
        new Dt("20031113T193000", false),
        new Dt("20031120T193000", false),
        new Dt("20031204T193000", false),
        new Dt("20031110T160000", false),
        new Dt("20031111T110000", false),
        new Dt("20031118T160000", false),
        new Dt("20031124T160000", false),
        new Dt("20031124T160000", false),
        new Dt("20031201T160000", false),
        new Dt("20031212T120000", false),
        new Dt("20031106T200000", false),
        new Dt("20031206T200000", false),
        new Dt("20031203T190000", false),
        new Dt("20031204T200000", false),
        new Dt("20031212T200000", false),
        new Dt("20031213T190000", false),
        new Dt("20031027T193000", true),
        new Dt("20031105T104500", false),
        new Dt("20031114T110000", false),
        new Dt("20031030T173000", true),
        new Dt("20031030T183000", true),
        new Dt("20031101T190000", false),
        new Dt("20031105T180000", false),
        new Dt("20031107T183000", false),
        new Dt("20031109T120000", false),
        new Dt("20031112T183000", false),
        new Dt("20031113T180000", false),
        new Dt("20031119T193000", false),
        new Dt("20031119T170000", false),
        new Dt("20031121T173000", false),
        new Dt("20031202T180000", false),
        new Dt("20031203T173000", false),
        new Dt("20031204T180000", false),
        new Dt("20031211T180000", false),
        new Dt("20031212T173000", false),
        new Dt("20031214T100000", false),
        new Dt("20031220T200000", false),
        new Dt("20031105T160000", false),
        new Dt("20031106T103000", false),
        new Dt("20031101T170000", false),
        new Dt("20031031T110000", true),
        new Dt("20031105T160000", false),
        new Dt("20031105T150000", false),
        new Dt("20031104T153000", false),
        new Dt("20031118T170000", false),
        new Dt("20031104T160000", false),
        new Dt("20031119T130000", false),
        new Dt("20031107T103000", false),
        new Dt("20031108T100000", false),
        new Dt("20031105T120000", false),
        new Dt("20031114T180000", false),
        new Dt("20031113T160000", false),
        new Dt("20031112T160000", false),
        new Dt("20031111T160000", false),
        new Dt("20031203T170000", false),
        new Dt("20031117T113000", false),
        new Dt("20031112T160000", false),
        new Dt("20031115T193000", false),
        new Dt("20031118T190000", false),
        new Dt("20031115T100000", false),
        new Dt("20031115T123000", false),
        new Dt("20031112T160000", false),
        new Dt("20031114T103000", false),
        new Dt("20031113T180000", false),
        new Dt("20031114T180000", false),
        new Dt("20031120T160000", false),
        new Dt("20031118T180000", false),
        new Dt("20031119T160000", false),
        new Dt("20031118T153000", false),
        new Dt("20031119T190000", false),
        new Dt("20031118T170000", false),
        new Dt("20031121T103000", false),
        new Dt("20031122T100000", false),
        new Dt("20031122T180000", false),
        new Dt("20031126T100000", false),
        new Dt("20031125T160000", false),
        new Dt("20031205T160000", false),
        new Dt("20050909T200000", true),
        new Dt("20050904T180000", true),
        new Dt("20040211T200000", false),
        new Dt("20040223T100000", false),
        new Dt("20040418T200000", true),
        new Dt("20040423T200000", true),
        new Dt("20040426T200000", true),
        new Dt("20040430T200000", true),
        new Dt("20040426T160000", true),
        new Dt("20040303T171500", true),
        new Dt("20060308T180000", true),
        new Dt("20060315T180000", true),
        new Dt("20040317T171500", true),
        new Dt("20040324T171500", true),
        new Dt("20040331T171500", true),
        new Dt("20040114T190000", false),
        new Dt("20040224T190000", false),
        new Dt("20040402T190000", true),
        new Dt("20040512T190000", true),
        new Dt("20031216T083000", false),
        new Dt("20031209T113000", false),
        new Dt("20031202T110000", false),
        new Dt("20031206T180000", false),
        new Dt("20031201T160000", false),
        new Dt("20031201T090000", false),
        new Dt("20031205T104500", false),
        new Dt("20031201T090000", false),
        new Dt("20031202T110000", false),
        new Dt("20031201T133000", false),
        new Dt("20031204T130000", false),
        new Dt("20031210T093000", false),
        new Dt("20031205T160000", false),
        new Dt("20031206T090000", false),
        new Dt("20031216T100000", false),
        new Dt("20040108T120000", false),
        new Dt("20031201T160000", false),
        new Dt("20031205T193000", false),
        new Dt("20031202T100000", false),
        new Dt("20031206T120000", false),
        new Dt("20031208T150000", false),
        new Dt("20031209T083000", false),
        new Dt("20031211T120000", false),
        new Dt("20031203T160000", false),
        new Dt("20031201T103000", false),
        new Dt("20031203T190000", false),
        new Dt("20031204T090000", false),
        new Dt("20031201T153000", false),
        new Dt("20031202T140000", false),
        new Dt("20031204T150000", false),
        new Dt("20031203T180000", false),
        new Dt("20031210T180000", false),
        new Dt("20031204T180000", false),
        new Dt("20031206T083000", false),
        new Dt("20031209T130000", false),
        new Dt("20031204T210000", false),
        new Dt("20031202T150000", false),
        new Dt("20031202T161000", false),
        new Dt("20031208T113000", false),
        new Dt("20031209T163000", false),
        new Dt("20031205T160000", false),
        new Dt("20031211T143000", false),
        new Dt("20031203T150000", false),
        new Dt("20031215T163000", false),
        new Dt("20031207T160000", false),
        new Dt("20031204T160000", false),
        new Dt("20031212T180000", false),
        new Dt("20031207T120000", false),
        new Dt("20031207T103000", false),
        new Dt("20031211T160000", false),
        new Dt("20040106T180000", false),
        new Dt("20040109T190000", false),
        new Dt("20040119T113000", false),
        new Dt("20040119T123000", false),
        new Dt("20040119T200000", false),
        new Dt("20040113T190000", false),
        new Dt("20031208T200000", false),
        new Dt("20040116T200000", false),
        new Dt("20040117T160000", false),
        new Dt("20040120T200000", false),
        new Dt("20040123T200000", false),
        new Dt("20040124T160000", false),
        new Dt("20040130T200000", false),
        new Dt("20040131T160000", false),
        new Dt("20040206T200000", false),
        new Dt("20040207T160000", false),
        new Dt("20040213T200000", false),
        new Dt("20040214T160000", false),
        new Dt("20040217T200000", false),
        new Dt("20040220T200000", false),
        new Dt("20040221T160000", false),
        new Dt("20040118T110000", false),
        new Dt("20040124T120000", false),
        new Dt("20040207T110000", false),
        new Dt("20040214T110000", false),
        new Dt("20040221T100000", false),
        new Dt("20040222T100000", false),
        new Dt("20040227T140000", false),
        new Dt("20031216T180000", false),
        new Dt("20031217T160000", false),
        new Dt("20031229T140000", false),
        new Dt("20031230T130000", false),
        new Dt("20040106T170000", false),
        new Dt("20040108T180000", false),
        new Dt("20040116T180000", false),
        new Dt("20040117T140000", false),
        new Dt("20040120T180000", false),
        new Dt("20040123T180000", false),
        new Dt("20040124T140000", false),
        new Dt("20040130T180000", false),
        new Dt("20040131T140000", false),
        new Dt("20040206T180000", false),
        new Dt("20040207T140000", false),
        new Dt("20040210T190000", false),
        new Dt("20040213T180000", false),
        new Dt("20040214T140000", false),
        new Dt("20040217T180000", false),
        new Dt("20040220T180000", false),
        new Dt("20040221T140000", false),
        new Dt("20031209T100000", false),
        new Dt("20031209T160000", false),
        new Dt("20040109T190000", false),
        new Dt("20040110T150000", false),
        new Dt("20040116T190000", false),
        new Dt("20040117T150000", false),
        new Dt("20040123T190000", false),
        new Dt("20040124T150000", false),
        new Dt("20040130T190000", false),
        new Dt("20040131T190000", false),
        new Dt("20040214T120000", false),
        new Dt("20040215T120000", false),
        new Dt("20040222T130000", false),
        new Dt("20040110T120000", false),
        new Dt("20040117T120000", false),
        new Dt("20040121T160000", false),
        new Dt("20040124T130000", false),
        new Dt("20040125T090000", false),
        new Dt("20040207T140000", false),
        new Dt("20031213T130000", false),
        new Dt("20040113T160000", false),
        new Dt("20040120T160000", false),
        new Dt("20031212T120000", false),
        new Dt("20040204T093000", false),
        new Dt("20040204T133000", false),
        new Dt("20040211T133000", false),
        new Dt("20040211T093000", false),
        new Dt("20031213T125500", false),
        new Dt("20040129T193000", false),
        new Dt("20040401T193000", true),
        new Dt("20040920T100000", true),
        new Dt("20031218T060000", false),
        new Dt("20040218T100000", false),
        new Dt("20040127T130000", false),
        new Dt("20040128T083000", false),
        new Dt("20040122T080000", false),
        new Dt("20031223T210000", false),
        new Dt("20040214T103000", false),
        new Dt("20040128T160000", false),
        new Dt("20040129T040000", false),
        new Dt("20040227T103000", false),
        new Dt("20040317T100000", true),
        new Dt("20040207T130000", false),
        new Dt("20040121T130000", false),
        new Dt("20040127T160000", false),
        new Dt("20050208T160000", false),
        new Dt("20040929T140000", true),
        new Dt("20050222T180000", false),
        new Dt("20050202T120000", false),
        new Dt("20040421T160000", true),
        new Dt("20040128T160000", false),
        new Dt("20040203T140000", false),
        new Dt("20040205T160000", false),
        new Dt("20040211T160000", false),
        new Dt("20040218T160000", false),
        new Dt("20040218T160000", false),
        new Dt("20040304T160000", true),
        new Dt("20040317T160000", true),
        new Dt("20040324T160000", true),
        new Dt("20040414T160000", true),
        new Dt("20040428T160000", true),
        new Dt("20040112T090000", false),
        new Dt("20050119T112500", false),
        new Dt("20040108T090000", false),
        new Dt("20040109T090000", false),
        new Dt("20040121T160000", false),
        new Dt("20040317T160000", true),
        new Dt("20040407T160000", true),
        new Dt("20041004T090000", true),
        new Dt("20040126T160000", false),
        new Dt("20040203T160000", false),
        new Dt("20050131T090000", false),
        new Dt("20040202T090000", false),
        new Dt("20040112T124000", false),
        new Dt("20040216T090000", false),
        new Dt("20040113T153000", false),
        new Dt("20040301T090000", true),
        new Dt("20040128T180000", false),
        new Dt("20040113T200000", false),
        new Dt("20040114T190000", false),
        new Dt("20040907T190000", true),
        new Dt("20040115T180000", false),
        new Dt("20040915T180000", true),
        new Dt("20051011T183000", true),
        new Dt("20040916T110000", true),
        new Dt("20040917T120000", true),
        new Dt("20040129T120000", false),
        new Dt("20040205T180000", false),
        new Dt("20040317T160000", true),
        new Dt("20040116T200000", false),
        new Dt("20040123T200000", false),
        new Dt("20040130T200000", false),
        new Dt("20040117T200000", false),
        new Dt("20040124T120000", false),
        new Dt("20040131T190000", false),
        new Dt("20040206T200000", false),
        new Dt("20040121T200000", false),
        new Dt("20040211T200000", false),
        new Dt("20040303T200000", true),
        new Dt("20040123T103000", false),
        new Dt("20040317T200000", true),
        new Dt("20040407T200000", true),
        new Dt("20040130T090000", false),
        new Dt("20040120T170000", false),
        new Dt("20040121T150000", false),
        new Dt("20040121T173000", false),
        new Dt("20040209T160000", false),
        new Dt("20040303T180000", true),
        new Dt("20040322T160000", true),
        new Dt("20040412T160000", true),
        new Dt("20040420T160000", true),
        new Dt("20040419T160000", true),
        new Dt("20040123T163000", false),
        new Dt("20040212T160000", false),
        new Dt("20040123T200000", false),
        new Dt("20040131T200000", false),
        new Dt("20040206T190000", false),
        new Dt("20040220T190000", false),
        new Dt("20040207T160000", false),
        new Dt("20040221T190000", false),
        new Dt("20040220T200000", false),
        new Dt("20040220T200000", false),
        new Dt("20040227T200000", false),
        new Dt("20040228T193000", false),
        new Dt("20040229T150000", false),
        new Dt("20040126T120000", false),
        new Dt("20040126T100000", false),
        new Dt("20040127T150000", false),
        new Dt("20040126T110000", false),
        new Dt("20050928T170000", true),
        new Dt("20040218T170000", false),
        new Dt("20040405T170000", true),
        new Dt("20040121T180000", false),
        new Dt("20040218T180000", false),
        new Dt("20040225T100000", false),
        new Dt("20040303T100000", true),
        new Dt("20040428T180000", true),
        new Dt("20040324T100000", true),
        new Dt("20040324T130000", true),
        new Dt("20040331T100000", true),
        new Dt("20040407T100000", true),
        new Dt("20040414T100000", true),
        new Dt("20040421T100000", true),
        new Dt("20040428T130000", true),
        new Dt("20040122T160000", false),
        new Dt("20040122T173000", false),
        new Dt("20060913T160000", true),
        new Dt("20040123T150000", false),
        new Dt("20040930T170000", true),
        new Dt("20040929T120000", true),
        new Dt("20040128T120000", false),
        new Dt("20040204T120000", false),
        new Dt("20040122T120000", false),
        new Dt("20040128T130000", false),
        new Dt("20040126T160000", false),
        new Dt("20040217T120000", false),
        new Dt("20040203T160000", false),
        new Dt("20040303T120000", true),
        new Dt("20040129T160000", false),
        new Dt("20040907T120000", true),
        new Dt("20040126T173000", false),
        new Dt("20040128T120000", false),
        new Dt("20040128T200000", false),
        new Dt("20040126T160000", false),
        new Dt("20040128T150000", false),
        new Dt("20040202T160000", false),
        new Dt("20040126T083000", false),
        new Dt("20040130T103000", false),
        new Dt("20040130T140000", false),
        new Dt("20040204T103000", false),
        new Dt("20040320T130000", true),
        new Dt("20040512T180000", true),
        new Dt("20040407T180000", true),
        new Dt("20040609T180000", true),
        new Dt("20040324T180000", true),
        new Dt("20040413T180000", true),
        new Dt("20040421T180000", true),
        new Dt("20040505T180000", true),
        new Dt("20040429T040000", true),
        new Dt("20040224T220000", false),
        new Dt("20040611T190000", true),
        new Dt("20040209T160000", false),
        new Dt("20040223T160000", false),
        new Dt("20040301T160000", true),
        new Dt("20040315T160000", true),
        new Dt("20040304T120000", true),
        new Dt("20040305T070000", true),
        new Dt("20040314T120000", true),
        new Dt("20040322T160000", true),
        new Dt("20040329T160000", true),
        new Dt("20040203T153000", false),
        new Dt("20040405T160000", true),
        new Dt("20040419T160000", true),
        new Dt("20040213T120000", false),
        new Dt("20040204T143000", false),
        new Dt("20040224T160000", false),
        new Dt("20040315T120000", true),
        new Dt("20040409T120000", true),
        new Dt("20040130T140000", false),
        new Dt("20040304T150000", true),
        new Dt("20040204T150000", false),
        new Dt("20040206T150000", false),
        new Dt("20040207T190000", false),
        new Dt("20040217T160000", false),
        new Dt("20040227T200000", false),
        new Dt("20040205T040000", false),
        new Dt("20040213T120000", false),
        new Dt("20040206T153000", false),
        new Dt("20040206T103000", false),
        new Dt("20040223T090000", false),
        new Dt("20040203T110000", false),
        new Dt("20040319T220000", true),
        new Dt("20040327T090000", true),
        new Dt("20040319T200000", true),
        new Dt("20040320T200000", true),
        new Dt("20040326T200000", true),
        new Dt("20040327T200000", true),
        new Dt("20040210T153000", false),
        new Dt("20040206T153000", false),
        new Dt("20061014T060000", true),
        new Dt("20040207T184500", false),
        new Dt("20050415T150000", true),
        new Dt("20040213T113000", false),
        new Dt("20040206T073000", false),
        new Dt("20040319T080000", true),
        new Dt("20040521T080000", true),
        new Dt("20040206T130000", false),
        new Dt("20040224T100000", false),
        new Dt("20051024T183000", true),
        new Dt("20050224T180000", false),
        new Dt("20040210T170000", false),
        new Dt("20040211T180000", false),
        new Dt("20040211T120000", false),
        new Dt("20040209T103000", false),
        new Dt("20040207T080000", false),
        new Dt("20040224T090000", false),
        new Dt("20040321T190000", true),
        new Dt("20040404T103000", true),
        new Dt("20040210T160000", false),
        new Dt("20040503T173000", true),
        new Dt("20040213T103000", false),
        new Dt("20040212T130000", false),
        new Dt("20040217T120000", false),
        new Dt("20040211T190000", false),
        new Dt("20040219T160000", false),
        new Dt("20040304T170000", true),
        new Dt("20040225T170000", false),
        new Dt("20040225T093000", false),
        new Dt("20040225T103000", false),
        new Dt("20040226T163000", false),
        new Dt("20040226T173000", false),
        new Dt("20040225T120000", false),
        new Dt("20050416T093000", true),
        new Dt("20040209T140000", false),
        new Dt("20040212T160000", false),
        new Dt("20040324T090000", true),
        new Dt("20040212T100000", false),
        new Dt("20040213T100000", false),
        new Dt("20040217T110000", false),
        new Dt("20040220T100000", false),
        new Dt("20040220T130000", false),
        new Dt("20040222T120000", false),
        new Dt("20040211T113000", false),
        new Dt("20040324T113000", true),
        new Dt("20040414T113000", true),
        new Dt("20040214T100000", false),
        new Dt("20040320T100000", true),
        new Dt("20040421T100000", true),
        new Dt("20040425T173000", true),
        new Dt("20050309T180000", true),
        new Dt("20050225T160000", false),
        new Dt("20050214T140000", false),
        new Dt("20040414T120000", true),
        new Dt("20040414T170000", true),
        new Dt("20040512T120000", true),
        new Dt("20040209T160000", false),
        new Dt("20040223T160000", false),
        new Dt("20040301T160000", true),
        new Dt("20040225T150000", false),
        new Dt("20040221T020000", false),
        new Dt("20050225T160000", false),
        new Dt("20050214T160000", false),
        new Dt("20040220T103000", false),
        new Dt("20040225T183000", false),
        new Dt("20040213T190000", false),
        new Dt("20040226T170000", false),
        new Dt("20040228T170000", false),
        new Dt("20040307T111500", true),
        new Dt("20040227T200000", false),
        new Dt("20040217T190000", false),
        new Dt("20040311T180000", true),
        new Dt("20040219T030000", false),
        new Dt("20040225T190000", false),
        new Dt("20040220T163000", false),
        new Dt("20040225T160000", false),
        new Dt("20040225T100000", false),
        new Dt("20050210T113000", false),
        new Dt("20040228T183000", false),
        new Dt("20040217T180000", false),
        new Dt("20051107T183000", false),
        new Dt("20051026T183000", true),
        new Dt("20041004T180000", true),
        new Dt("20040223T180000", false),
        new Dt("20040224T190000", false),
        new Dt("20040221T200000", false),
        new Dt("20040318T200000", true),
        new Dt("20040224T100000", false),
        new Dt("20041006T180000", true),
        new Dt("20040225T180000", false),
        new Dt("20040225T180000", false),
        new Dt("20051026T183000", true),
        new Dt("20051108T160000", false),
        new Dt("20051024T183000", true),
        new Dt("20050908T183000", true),
        new Dt("20040221T200000", false),
        new Dt("20040225T160000", false),
        new Dt("20040226T100000", false),
        new Dt("20050225T103000", false),
        new Dt("20040225T120000", false),
        new Dt("20050222T160000", false),
        new Dt("20040223T192000", false),
        new Dt("20040303T180000", true),
        new Dt("20040305T160000", true),
        new Dt("20040309T193000", true),
        new Dt("20040407T080000", true),
        new Dt("20040225T160000", false),
        new Dt("20040226T040000", false),
        new Dt("20040302T193000", true),
        new Dt("20040319T193000", true),
        new Dt("20040329T193000", true),
        new Dt("20040227T093000", false),
        new Dt("20040310T113000", true),
        new Dt("20040304T040000", true),
        new Dt("20040302T110000", true),
        new Dt("20040520T120000", true),
        new Dt("20040405T160000", true),
        new Dt("20040407T160000", true),
        new Dt("20040414T160000", true),
        new Dt("20040301T090000", true),
        new Dt("20040407T120000", true),
        new Dt("20040224T153000", false),
        new Dt("20040313T123000", true),
        new Dt("20040315T160000", true),
        new Dt("20040324T150000", true),
        new Dt("20040326T150000", true),
        new Dt("20040409T150000", true),
        new Dt("20041106T083000", false),
        new Dt("20041213T150000", false),
        new Dt("20041213T160000", false),
        new Dt("20040311T120000", true),
        new Dt("20040316T100000", true),
        new Dt("20040318T130000", true),
        new Dt("20040325T100000", true),
        new Dt("20040329T100000", true),
        new Dt("20040330T130000", true),
        new Dt("20040331T083000", true),
        new Dt("20040317T113000", true),
        new Dt("20040325T113000", true),
        new Dt("20040405T090000", true),
        new Dt("20040318T160000", true),
        new Dt("20040315T160000", true),
        new Dt("20040303T200000", true),
        new Dt("20040305T103000", true),
        new Dt("20040323T150000", true),
        new Dt("20040406T150000", true),
        new Dt("20040330T150000", true),
        new Dt("20040303T120000", true),
        new Dt("20040316T160000", true),
        new Dt("20040327T193000", true),
        new Dt("20040403T090000", true),
        new Dt("20040326T090000", true),
        new Dt("20040327T083000", true),
        new Dt("20040403T090000", true),
        new Dt("20041113T090000", false),
        new Dt("20051022T090000", true),
        new Dt("20040911T090000", true),
        new Dt("20040324T090000", true),
        new Dt("20040310T150000", true),
        new Dt("20040414T120000", true),
        new Dt("20040426T160000", true),
        new Dt("20040422T110000", true),
        new Dt("20040914T193000", true),
        new Dt("20040915T100000", true),
        new Dt("20041001T170000", true),
        new Dt("20040322T193000", true),
        new Dt("20040923T180000", true),
        new Dt("20041019T180000", true),
        new Dt("20040407T110000", true),
        new Dt("20040329T140000", true),
        new Dt("20040326T173000", true),
        new Dt("20040327T070000", true),
        new Dt("20040328T140000", true),
        new Dt("20040402T160000", true),
        new Dt("20040330T180000", true),
        new Dt("20040327T080000", true),
        new Dt("20040328T080000", true),
        new Dt("20040328T160000", true),
        new Dt("20040401T090000", true),
        new Dt("20040401T193000", true),
        new Dt("20040327T170000", true),
        new Dt("20040326T120000", true),
        new Dt("20040327T120000", true),
        new Dt("20040331T170000", true),
        new Dt("20040326T200000", true),
        new Dt("20040326T180000", true),
        new Dt("20040326T190000", true),
        new Dt("20040326T200000", true),
        new Dt("20040329T090000", true),
        new Dt("20040329T180000", true),
        new Dt("20040329T190000", true),
        new Dt("20040329T093000", true),
        new Dt("20040329T140000", true),
        new Dt("20040330T120000", true),
        new Dt("20040331T153000", true),
        new Dt("20040330T193000", true),
        new Dt("20040330T190000", true),
        new Dt("20040330T180000", true),
        new Dt("20040330T193000", true),
        new Dt("20040330T220000", true),
        new Dt("20040402T190000", true),
        new Dt("20040402T200000", true),
        new Dt("20040402T120000", true),
        new Dt("20040331T100000", true),
        new Dt("20040402T010000", true),
        new Dt("20040331T150000", true),
        new Dt("20040331T120000", true),
        new Dt("20040331T090000", true),
        new Dt("20040331T193000", true),
        new Dt("20040331T103000", true),
        new Dt("20040331T190000", true),
        new Dt("20040323T150000", true),
        new Dt("20040324T183000", true),
        new Dt("20040329T160000", true),
        new Dt("20040319T160000", true),
        new Dt("20040316T153000", true),
        new Dt("20040323T153000", true),
        new Dt("20040421T160000", true),
        new Dt("20040406T153000", true),
        new Dt("20040413T153000", true),
        new Dt("20040322T160000", true),
        new Dt("20040324T160000", true),
        new Dt("20040405T130000", true),
        new Dt("20040319T153000", true),
        new Dt("20040316T180000", true),
        new Dt("20040330T160000", true),
        new Dt("20040326T103000", true),
        new Dt("20040510T140000", true),
        new Dt("20040324T180000", true),
        new Dt("20040410T100000", true),
        new Dt("20040409T170000", true),
        new Dt("20040322T160000", true),
        new Dt("20040416T150000", true),
        new Dt("20040330T100000", true),
        new Dt("20040323T100000", true),
        new Dt("20040325T160000", true),
        new Dt("20040323T103000", true),
        new Dt("20040402T103000", true),
        new Dt("20040409T103000", true),
        new Dt("20040416T103000", true),
        new Dt("20040416T140000", true),
        new Dt("20040423T103000", true),
        new Dt("20040330T160000", true),
        new Dt("20040330T120000", true),
        new Dt("20040414T160000", true),
        new Dt("20040401T040000", true),
        new Dt("20040412T130000", true),
        new Dt("20040402T140000", true),
        new Dt("20040415T180000", true),
        new Dt("20040331T113000", true),
        new Dt("20040329T160000", true),
        new Dt("20040405T170000", true),
        new Dt("20040423T150000", true),
        new Dt("20040331T140000", true),
        new Dt("20040913T163000", true),
        new Dt("20040924T120000", true),
        new Dt("20040421T180000", true),
        new Dt("20040422T180000", true),
        new Dt("20040420T173000", true),
        new Dt("20040419T160000", true),
        new Dt("20040421T120000", true),
        new Dt("20040421T150000", true),
        new Dt("20040422T160000", true),
        new Dt("20040419T100000", true),
        new Dt("20040420T100000", true),
        new Dt("20040421T180000", true),
        new Dt("20040422T100000", true),
        new Dt("20040423T100000", true),
        new Dt("20040426T180000", true),
        new Dt("20040422T180000", true),
        new Dt("20040331T120000", true),
        new Dt("20040408T120000", true),
        new Dt("20040413T130000", true),
        new Dt("20040330T193000", true),
        new Dt("20040416T181500", true),
        new Dt("20040408T180000", true),
        new Dt("20040409T193000", true),
        new Dt("20040407T160000", true),
        new Dt("20040406T130000", true),
        new Dt("20040412T130000", true),
        new Dt("20040413T130000", true),
        new Dt("20040419T130000", true),
        new Dt("20040420T130000", true),
        new Dt("20040426T130000", true),
        new Dt("20040427T130000", true),
        new Dt("20040408T040000", true),
        new Dt("20040407T090000", true),
        new Dt("20040403T080000", true),
        new Dt("20040419T160000", true),
        new Dt("20040417T100000", true),
        new Dt("20040426T160000", true),
        new Dt("20040503T105500", true),
        new Dt("20040407T120000", true),
        new Dt("20040409T130000", true),
        new Dt("20040416T120000", true),
        new Dt("20040416T200000", true),
        new Dt("20040417T200000", true),
        new Dt("20040418T140000", true),
        new Dt("20040423T200000", true),
        new Dt("20040422T200000", true),
        new Dt("20040424T200000", true),
        new Dt("20040409T190000", true),
        new Dt("20040507T190000", true),
        new Dt("20040417T170000", true),
        new Dt("20040423T200000", true),
        new Dt("20040424T193000", true),
        new Dt("20040410T190000", true),
        new Dt("20040419T200000", true),
        new Dt("20040514T050000", true),
        new Dt("20040423T200000", true),
        new Dt("20040430T200000", true),
        new Dt("20040417T100000", true),
        new Dt("20040417T140000", true),
        new Dt("20040421T120000", true),
        new Dt("20040421T150000", true),
        new Dt("20040422T120000", true),
        new Dt("20040423T150000", true),
        new Dt("20040421T110000", true),
        new Dt("20040415T120000", true),
        new Dt("20040415T103000", true),
        new Dt("20040502T160000", true),
        new Dt("20040415T140000", true),
        new Dt("20040416T160000", true),
        new Dt("20040415T040000", true),
        new Dt("20040416T114500", true),
        new Dt("20040415T183000", true),
        new Dt("20040419T160000", true),
        new Dt("20040421T110000", true),
        new Dt("20040421T170000", true),
        new Dt("20040510T180000", true),
        new Dt("20040419T160000", true),
        new Dt("20040422T040000", true),
        new Dt("20040430T093000", true),
        new Dt("20040421T120000", true),
        new Dt("20040424T160000", true),
        new Dt("20040514T170000", true),
        new Dt("20040515T120000", true),
        new Dt("20040519T183000", true),
        new Dt("20040613T090000", true),
        new Dt("20040421T120000", true),
        new Dt("20040422T130000", true),
        new Dt("20040425T190000", true),
        new Dt("20040423T070000", true),
        new Dt("20040430T120000", true),
        new Dt("20040428T153000", true),
        new Dt("20040423T190000", true),
        new Dt("20040424T190000", true),
        new Dt("20040430T190000", true),
        new Dt("20040501T190000", true),
        new Dt("20040428T100000", true),
        new Dt("20040427T070000", true),
        new Dt("20040511T200000", true),
        new Dt("20040512T090000", true),
        new Dt("20040513T110000", true),
        new Dt("20040430T190000", true),
        new Dt("20040430T210000", true),
        new Dt("20040501T200000", true),
        new Dt("20040507T193000", true),
        new Dt("20040515T193000", true),
        new Dt("20040514T193000", true),
        new Dt("20040508T170000", true),
        new Dt("20040510T140000", true),
        new Dt("20040513T120000", true),
        new Dt("20040501T100000", true),
        new Dt("20040510T123000", true),
        new Dt("20041103T090000", false),
        new Dt("20040429T140000", true),
        new Dt("20040527T120000", true),
        new Dt("20040902T180000", true),
        new Dt("20040510T103000", true),
        new Dt("20040512T140000", true),
        new Dt("20040519T103000", true),
        new Dt("20040512T103000", true),
        new Dt("20040514T103000", true),
        new Dt("20040514T140000", true),
        new Dt("20040517T140000", true),
        new Dt("20040517T103000", true),
        new Dt("20040521T103000", true),
        new Dt("20040521T140000", true),
        new Dt("20040524T140000", true),
        new Dt("20040524T103000", true),
        new Dt("20040519T140000", true),
        new Dt("20040505T183000", true),
        new Dt("20040507T120000", true),
        new Dt("20040825T060000", true),
        new Dt("20041028T070000", true),
        new Dt("20040514T100000", true),
        new Dt("20040514T120000", true),
        new Dt("20040514T113000", true),
        new Dt("20040514T124500", true),
        new Dt("20040514T140000", true),
        new Dt("20040514T153000", true),
        new Dt("20040514T160000", true),
        new Dt("20040517T190000", true),
        new Dt("20040621T083000", true),
        new Dt("20040622T083000", true),
        new Dt("20040623T083000", true),
        new Dt("20040518T180000", true),
        new Dt("20040611T013000", true),
        new Dt("20040917T190000", true),
        new Dt("20041012T190000", true),
        new Dt("20040520T153000", true),
        new Dt("20040521T120000", true),
        new Dt("20040521T153000", true),
        new Dt("20040521T190000", true),
        new Dt("20040522T120000", true),
        new Dt("20040522T153000", true),
        new Dt("20040524T100500", true),
        new Dt("20040618T193000", true),
        new Dt("20040611T073000", true),
        new Dt("20040528T070000", true),
        new Dt("20040917T120000", true),
        new Dt("20040610T120000", true),
        new Dt("20040608T053000", true),
        new Dt("20040610T150000", true),
        new Dt("20040603T104500", true),
        new Dt("20040602T120000", true),
        new Dt("20040603T100000", true),
        new Dt("20040605T123000", true),
        new Dt("20040610T110000", true),
        new Dt("20040611T022500", true),
        new Dt("20040713T053000", true),
        new Dt("20041020T053000", true),
        new Dt("20040629T104500", true),
        new Dt("20040619T000000", true),
        new Dt("20040623T110000", true),
        new Dt("20040715T113000", true),
        new Dt("20040717T160000", true),
        new Dt("20040730T160000", true),
        new Dt("20040720T113000", true),
        new Dt("20040727T113000", true),
        new Dt("20040910T201000", true),
        new Dt("20040911T200000", true),
        new Dt("20040722T190000", true),
        new Dt("20040804T193000", true),
        new Dt("20040805T193000", true),
        new Dt("20040806T193000", true),
        new Dt("20040807T193000", true),
        new Dt("20040910T200000", true),
        new Dt("20040917T200000", true),
        new Dt("20040918T193000", true),
        new Dt("20040924T200000", true),
        new Dt("20041001T200000", true),
        new Dt("20041008T200000", true),
        new Dt("20041015T200000", true),
        new Dt("20041022T200000", true),
        new Dt("20041023T200000", true),
        new Dt("20041029T200000", true),
        new Dt("20041112T200000", false),
        new Dt("20041113T200000", false),
        new Dt("20041119T200000", false),
        new Dt("20041120T200000", false),
        new Dt("20041203T200000", false),
        new Dt("20041204T200000", false),
        new Dt("20040724T160000", true),
        new Dt("20040918T193000", true),
        new Dt("20040923T190000", true),
        new Dt("20040708T120000", true),
        new Dt("20041009T190000", true),
        new Dt("20041002T190000", true),
        new Dt("20041001T190000", true),
        new Dt("20041009T200000", true),
        new Dt("20040924T080000", true),
        new Dt("20040712T070000", true),
        new Dt("20041015T193000", true),
        new Dt("20041016T110000", true),
        new Dt("20041016T110000", true),
        new Dt("20041016T200000", true),
        new Dt("20041023T220000", true),
        new Dt("20041029T200000", true),
        new Dt("20041030T190000", true),
        new Dt("20040811T080000", true),
        new Dt("20041112T190000", false),
        new Dt("20041106T160000", false),
        new Dt("20041106T200000", false),
        new Dt("20041028T123000", true),
        new Dt("20041113T190000", false),
        new Dt("20040802T104500", true),
        new Dt("20041208T093000", false),
        new Dt("20041119T190000", false),
        new Dt("20041120T200000", false),
        new Dt("20041210T190000", false),
        new Dt("20040727T110000", true),
        new Dt("20040915T040000", true),
        new Dt("20040727T120000", true),
        new Dt("20040812T120000", true),
        new Dt("20040628T180000", true),
        new Dt("20041014T193000", true),
        new Dt("20040817T140000", true),
        new Dt("20040810T130000", true),
        new Dt("20040825T100000", true),
        new Dt("20040909T120000", true),
        new Dt("20040915T080000", true),
        new Dt("20040915T130000", true),
        new Dt("20040922T092500", true),
        new Dt("20041004T130000", true),
        new Dt("20041005T083000", true),
        new Dt("20041014T120000", true),
        new Dt("20041019T130000", true),
        new Dt("20041020T080000", true),
        new Dt("20041105T120000", false),
        new Dt("20041103T160000", false),
        new Dt("20041027T100000", true),
        new Dt("20041027T140000", true),
        new Dt("20041103T080000", false),
        new Dt("20041108T190000", false),
        new Dt("20041102T190000", false),
        new Dt("20041103T180000", false),
        new Dt("20041116T190000", false),
        new Dt("20041207T190000", false),
        new Dt("20041116T100000", false),
        new Dt("20041117T093000", false),
        new Dt("20041213T130000", false),
        new Dt("20041213T080000", false),
        new Dt("20041209T120000", false),
        new Dt("20041105T190000", false),
        new Dt("20041203T193000", false),
        new Dt("20041203T120000", false),
        new Dt("20041106T193000", false),
        new Dt("20040630T180000", true),
        new Dt("20040720T200000", true),
        new Dt("20040714T113000", true),
        new Dt("20040907T110000", true),
        new Dt("20040909T083000", true),
        new Dt("20040910T110000", true),
        new Dt("20040910T183000", true),
        new Dt("20040911T080000", true),
        new Dt("20040911T100000", true),
        new Dt("20040910T083000", true),
        new Dt("20040713T193000", true),
        new Dt("20040727T193000", true),
        new Dt("20040719T070000", true),
        new Dt("20040723T080000", true),
        new Dt("20040915T093000", true),
        new Dt("20040922T093000", true),
        new Dt("20040929T093000", true),
        new Dt("20041006T093000", true),
        new Dt("20041007T093000", true),
        new Dt("20041020T093000", true),
        new Dt("20041027T093000", true),
        new Dt("20041117T093000", false),
        new Dt("20041201T093000", false),
        new Dt("20041208T093000", false),
        new Dt("20040909T160000", true),
        new Dt("20040831T160000", true),
        new Dt("20040827T183000", true),
        new Dt("20040905T180000", true),
        new Dt("20040910T200000", true),
        new Dt("20040914T190000", true),
        new Dt("20040917T190000", true),
        new Dt("20040922T173000", true),
        new Dt("20041001T200000", true),
        new Dt("20041006T200000", true),
        new Dt("20041012T190000", true),
        new Dt("20041023T200000", true),
        new Dt("20041113T200000", false),
        new Dt("20041120T203000", false),
        new Dt("20041201T190000", false),
        new Dt("20041204T193000", false),
        new Dt("20041212T193000", false),
        new Dt("20040810T063500", true),
        new Dt("20040830T060000", true),
        new Dt("20040907T060000", true),
        new Dt("20040928T073000", true),
        new Dt("20040813T140000", true),
        new Dt("20040812T170000", true),
        new Dt("20040826T203000", true),
        new Dt("20040826T213000", true),
        new Dt("20040827T173000", true),
        new Dt("20040827T123000", true),
        new Dt("20040831T163000", true),
        new Dt("20040907T163000", true),
        new Dt("20040928T163000", true),
        new Dt("20040825T160000", true),
        new Dt("20040922T200000", true),
        new Dt("20041013T200000", true),
        new Dt("20041022T200000", true),
        new Dt("20041103T200000", false),
        new Dt("20041117T200000", false),
        new Dt("20041201T200000", false),
        new Dt("20041006T170000", true),
        new Dt("20041117T170000", false),
        new Dt("20041020T100000", true),
        new Dt("20041201T170000", false),
        new Dt("20040908T120000", true),
        new Dt("20040917T130000", true),
        new Dt("20040914T160000", true),
        new Dt("20040916T190000", true),
        new Dt("20040908T160000", true),
        new Dt("20040909T180000", true),
        new Dt("20040909T180000", true),
        new Dt("20041006T120000", true),
        new Dt("20041012T170000", true),
        new Dt("20041018T190000", true),
        new Dt("20040927T173000", true),
        new Dt("20041018T160000", true),
        new Dt("20041118T193000", false),
        new Dt("20041026T193000", true),
        new Dt("20040825T170000", true),
        new Dt("20050210T193000", false),
        new Dt("20040823T180000", true),
        new Dt("20040909T173000", true),
        new Dt("20041014T183000", true),
        new Dt("20040905T200000", true),
        new Dt("20040904T130000", true),
        new Dt("20041009T170000", true),
        new Dt("20041028T080000", true),
        new Dt("20041104T180000", false),
        new Dt("20041117T161000", false),
        new Dt("20040911T200000", true),
        new Dt("20040912T200000", true),
        new Dt("20040917T200000", true),
        new Dt("20040918T200000", true),
        new Dt("20040916T200000", true),
        new Dt("20040915T200000", true),
        new Dt("20041020T173000", true),
        new Dt("20041001T160000", true),
        new Dt("20050214T150000", false),
        new Dt("20051019T120000", true),
        new Dt("20041105T120000", false),
        new Dt("20040923T190000", true),
        new Dt("20040908T130000", true),
        new Dt("20040923T160000", true),
        new Dt("20040921T160000", true),
        new Dt("20040928T160000", true),
        new Dt("20040922T120000", true),
        new Dt("20041008T120000", true),
        new Dt("20040831T150000", true),
        new Dt("20041105T120000", false),
        new Dt("20041006T120000", true),
        new Dt("20040908T140000", true),
        new Dt("20040827T000000", true),
        new Dt("20040920T160000", true),
        new Dt("20040927T160000", true),
        new Dt("20041004T160000", true),
        new Dt("20051012T160000", true),
        new Dt("20041018T160000", true),
        new Dt("20040915T140000", true),
        new Dt("20040903T190000", true),
        new Dt("20040904T190000", true),
        new Dt("20040908T190000", true),
        new Dt("20040910T190000", true),
        new Dt("20040911T190000", true),
        new Dt("20040919T140000", true),
        new Dt("20041001T160000", true),
        new Dt("20040917T190000", true),
        new Dt("20040924T190000", true),
        new Dt("20040925T190000", true),
        new Dt("20040929T200000", true),
        new Dt("20041001T190000", true),
        new Dt("20041002T190000", true),
        new Dt("20041008T190000", true),
        new Dt("20041015T190000", true),
        new Dt("20041025T160000", true),
        new Dt("20040901T170000", true),
        new Dt("20041101T160000", false),
        new Dt("20041108T160000", false),
        new Dt("20041129T160000", false),
        new Dt("20040913T110000", true),
        new Dt("20040921T110000", true),
        new Dt("20040929T100000", true),
        new Dt("20040911T130000", true),
        new Dt("20040918T130000", true),
        new Dt("20040925T120000", true),
        new Dt("20040911T143000", true),
        new Dt("20040925T130000", true),
        new Dt("20040918T133000", true),
        new Dt("20040904T140000", true),
        new Dt("20040905T090000", true),
        new Dt("20040914T110000", true),
        new Dt("20040917T100000", true),
        new Dt("20040923T080000", true),
        new Dt("20040925T130000", true),
        new Dt("20040926T090000", true),
        new Dt("20040904T190000", true),
        new Dt("20040905T140000", true),
        new Dt("20040911T143000", true),
        new Dt("20040912T143000", true),
        new Dt("20040918T140000", true),
        new Dt("20040918T140000", true),
        new Dt("20040919T140000", true),
        new Dt("20040924T180000", true),
        new Dt("20040925T160000", true),
        new Dt("20040929T160000", true),
        new Dt("20040902T160000", true),
        new Dt("20040908T190000", true),
        new Dt("20040911T130000", true),
        new Dt("20040914T190000", true),
        new Dt("20040916T170000", true),
        new Dt("20040924T150000", true),
        new Dt("20040925T130000", true),
        new Dt("20040929T160000", true),
        new Dt("20040908T160000", true),
        new Dt("20040911T140000", true),
        new Dt("20040912T140000", true),
        new Dt("20040918T140000", true),
        new Dt("20040924T160000", true),
        new Dt("20040925T140000", true),
        new Dt("20040905T100000", true),
        new Dt("20040904T090000", true),
        new Dt("20040909T160000", true),
        new Dt("20040911T110000", true),
        new Dt("20040912T130000", true),
        new Dt("20040916T160000", true),
        new Dt("20040918T140000", true),
        new Dt("20040924T083000", true),
        new Dt("20040925T083000", true),
        new Dt("20040928T160000", true),
        new Dt("20041111T153000", false),
        new Dt("20040918T063000", true),
        new Dt("20041006T113000", true),
        new Dt("20041217T120000", false),
        new Dt("20041008T160000", true),
        new Dt("20041009T140000", true),
        new Dt("20041013T180000", true),
        new Dt("20041016T160000", true),
        new Dt("20041017T120000", true),
        new Dt("20041022T150000", true),
        new Dt("20041023T130000", true),
        new Dt("20041027T190000", true),
        new Dt("20041001T160000", true),
        new Dt("20041008T160000", true),
        new Dt("20041009T140000", true),
        new Dt("20041013T190000", true),
        new Dt("20041023T160000", true),
        new Dt("20041026T160000", true),
        new Dt("20041027T130000", true),
        new Dt("20041001T160000", true),
        new Dt("20041003T140000", true),
        new Dt("20041005T153000", true),
        new Dt("20041009T090000", true),
        new Dt("20041015T083000", true),
        new Dt("20041003T190000", true),
        new Dt("20041030T140000", true),
        new Dt("20041105T190000", false),
        new Dt("20041106T150000", false),
        new Dt("20041109T190000", false),
        new Dt("20041113T190000", false),
        new Dt("20041114T150000", false),
        new Dt("20041119T190000", false),
        new Dt("20041120T150000", false),
        new Dt("20041123T190000", false),
        new Dt("20041203T190000", false),
        new Dt("20041204T150000", false),
        new Dt("20050108T150000", false),
        new Dt("20050109T140000", false),
        new Dt("20050115T150000", false),
        new Dt("20050116T130000", false),
        new Dt("20050121T190000", false),
        new Dt("20050122T150000", false),
        new Dt("20050128T190000", false),
        new Dt("20050129T160000", false),
        new Dt("20050204T190000", false),
        new Dt("20050206T140000", false),
        new Dt("20050212T150000", false),
        new Dt("20050213T130000", false),
        new Dt("20050219T150000", false),
        new Dt("20041005T150000", true),
        new Dt("20041105T200000", false),
        new Dt("20041106T200000", false),
        new Dt("20041112T200000", false),
        new Dt("20041113T200000", false),
        new Dt("20040210T200000", false),
        new Dt("20040211T200000", false),
        new Dt("20040212T140000", false),
        new Dt("20040408T200000", true),
        new Dt("20040409T200000", true),
        new Dt("20040414T200000", true),
        new Dt("20040415T200000", true),
        new Dt("20040416T200000", true),
        new Dt("20041107T140000", false),
        new Dt("20040911T120000", true),
        new Dt("20041127T170000", false),
        new Dt("20041130T193000", false),
        new Dt("20041207T180000", false),
        new Dt("20050104T180000", false),
        new Dt("20050114T180000", false),
        new Dt("20050115T140000", false),
        new Dt("20050118T180000", false),
        new Dt("20050121T180000", false),
        new Dt("20050122T140000", false),
        new Dt("20050128T180000", false),
        new Dt("20050129T140000", false),
        new Dt("20050204T180000", false),
        new Dt("20050205T140000", false),
        new Dt("20050208T180000", false),
        new Dt("20050211T180000", false),
        new Dt("20050212T140000", false),
        new Dt("20050215T180000", false),
        new Dt("20050218T180000", false),
        new Dt("20040908T140000", true),
        new Dt("20041002T140000", true),
        new Dt("20041009T130000", true),
        new Dt("20041023T130000", true),
        new Dt("20041030T130000", true),
        new Dt("20041113T130000", false),
        new Dt("20041106T120000", false),
        new Dt("20040910T190500", true),
        new Dt("20040915T073000", true),
        new Dt("20040915T183000", true),
        new Dt("20040916T180000", true),
        new Dt("20040921T190500", true),
        new Dt("20040922T190500", true),
        new Dt("20040923T190000", true),
        new Dt("20041003T133000", true),
        new Dt("20041009T130000", true),
        new Dt("20041010T090000", true),
        new Dt("20041018T183000", true),
        new Dt("20041002T150000", true),
        new Dt("20041008T160000", true),
        new Dt("20041013T190000", true),
        new Dt("20041022T160000", true),
        new Dt("20041023T140000", true),
        new Dt("20041027T160000", true),
        new Dt("20041027T160000", true),
        new Dt("20041002T173000", true),
        new Dt("20041002T190000", true),
        new Dt("20041009T170500", true),
        new Dt("20041019T190000", true),
        new Dt("20041023T190000", true),
        new Dt("20041029T190000", true),
        new Dt("20041030T190000", true),
        new Dt("20041105T190000", false),
        new Dt("20040930T180000", true),
        new Dt("20041106T190000", false),
        new Dt("20041112T190000", false),
        new Dt("20041113T190000", false),
        new Dt("20041119T190000", false),
        new Dt("20041120T190000", false),
        new Dt("20041203T190000", false),
        new Dt("20041204T190000", false),
        new Dt("20041208T190000", false),
        new Dt("20041211T190000", false),
        new Dt("20050101T190500", false),
        new Dt("20050102T170500", false),
        new Dt("20050107T190000", false),
        new Dt("20050108T190000", false),
        new Dt("20050114T190000", false),
        new Dt("20050115T190000", false),
        new Dt("20050121T190000", false),
        new Dt("20050122T190000", false),
        new Dt("20050128T190000", false),
        new Dt("20050129T190000", false),
        new Dt("20050205T190000", false),
        new Dt("20050211T190000", false),
        new Dt("20050212T120000", false),
        new Dt("20050212T190000", false),
        new Dt("20050218T190000", false),
        new Dt("20050219T190000", false),
        new Dt("20050225T190000", false),
        new Dt("20050226T190000", false),
        new Dt("20041016T190000", true),
        new Dt("20041006T183000", true),
        new Dt("20041006T183000", true),
        new Dt("20041007T190000", true),
        new Dt("20041009T100000", true),
        new Dt("20041014T183000", true),
        new Dt("20041016T120000", true),
        new Dt("20041111T173000", false),
        new Dt("20040915T160000", true),
        new Dt("20041209T190000", false),
        new Dt("20040922T160000", true),
        new Dt("20040929T160000", true),
        new Dt("20041006T160000", true),
        new Dt("20041013T160000", true),
        new Dt("20041020T160000", true),
        new Dt("20041110T160000", false),
        new Dt("20041117T160000", false),
        new Dt("20040916T040000", true),
        new Dt("20041026T180000", true),
        new Dt("20041012T180000", true),
        new Dt("20040927T180000", true),
        new Dt("20041019T183000", true),
        new Dt("20040924T103000", true),
        new Dt("20040923T040000", true),
        new Dt("20040930T040000", true),
        new Dt("20051025T110000", true),
        new Dt("20050330T160000", true),
        new Dt("20040921T110000", true),
        new Dt("20041008T103000", true),
        new Dt("20041015T103000", true),
        new Dt("20040923T200000", true),
        new Dt("20041029T103000", true),
        new Dt("20041105T103000", false),
        new Dt("20041112T103000", false),
        new Dt("20041119T103000", false),
        new Dt("20041203T103000", false),
        new Dt("20041210T103000", false),
        new Dt("20040924T110000", true),
        new Dt("20041001T103000", true),
        new Dt("20041021T110000", true),
        new Dt("20041028T100000", true),
        new Dt("20040923T200000", true),
        new Dt("20040924T200000", true),
        new Dt("20040925T200000", true),
        new Dt("20040927T180000", true),
        new Dt("20041015T150000", true),
        new Dt("20041029T150000", true),
        new Dt("20041110T150000", false),
        new Dt("20041112T150000", false),
        new Dt("20041119T150000", false),
        new Dt("20040924T163000", true),
        new Dt("20040928T180000", true),
        new Dt("20041005T160000", true),
        new Dt("20040929T190000", true),
        new Dt("20040929T173000", true),
        new Dt("20051102T190000", false),
        new Dt("20040930T180000", true),
        new Dt("20041003T170000", true),
        new Dt("20041004T183000", true),
        new Dt("20050926T190000", true),
        new Dt("20041006T173000", true),
        new Dt("20041001T170000", true),
        new Dt("20041001T203000", true),
        new Dt("20041002T113000", true),
        new Dt("20041002T210000", true),
        new Dt("20040930T170000", true),
        new Dt("20041001T193000", true),
        new Dt("20041002T180000", true),
        new Dt("20041002T100000", true),
        new Dt("20041002T100000", true),
        new Dt("20041002T100000", true),
        new Dt("20041002T100000", true),
        new Dt("20041002T100000", true),
        new Dt("20041002T120000", true),
        new Dt("20041003T140000", true),
        new Dt("20040928T190000", true),
        new Dt("20040927T160000", true),
        new Dt("20041001T080000", true),
        new Dt("20041001T190000", true),
        new Dt("20041002T080000", true),
        new Dt("20041108T160000", false),
        new Dt("20041004T160000", true),
        new Dt("20041004T160000", true),
        new Dt("20041001T060000", true),
        new Dt("20041001T100000", true),
        new Dt("20041019T153000", true),
        new Dt("20041109T153000", false),
        new Dt("20041109T153000", false),
        new Dt("20041007T040000", true),
        new Dt("20041021T040000", true),
        new Dt("20041013T040000", true),
        new Dt("20041028T040000", true),
        new Dt("20041006T143000", true),
        new Dt("20041007T150000", true),
        new Dt("20041004T080000", true),
        new Dt("20061128T120000", false),
        new Dt("20041025T160000", true),
        new Dt("20041108T160000", false),
        new Dt("20041115T160000", false),
        new Dt("20041122T160000", false),
        new Dt("20041129T160000", false),
        new Dt("20041206T160000", false),
        new Dt("20041213T160000", false),
        new Dt("20041028T150000", true),
        new Dt("20041008T160000", true),
        new Dt("20041101T160000", false),
        new Dt("20041018T103000", true),
        new Dt("20041013T070000", true),
        new Dt("20041012T090000", true),
        new Dt("20041018T090000", true),
        new Dt("20041101T090000", false),
        new Dt("20041108T090000", false),
        new Dt("20041025T090000", true),
        new Dt("20041011T180000", true),
        new Dt("20041012T190000", true),
        new Dt("20051024T190000", true),
        new Dt("20051019T183000", true),
        new Dt("20041012T180000", true),
        new Dt("20041013T180000", true),
        new Dt("20041013T190000", true),
        new Dt("20041013T180000", true),
        new Dt("20051027T190000", true),
        new Dt("20041014T190000", true),
        new Dt("20041014T183000", true),
        new Dt("20051018T183000", true),
        new Dt("20041014T100000", true),
        new Dt("20041011T080000", true),
        new Dt("20041013T180000", true),
        new Dt("20051018T180000", true),
        new Dt("20050927T183000", true),
        new Dt("20051025T190000", true),
        new Dt("20041019T100000", true),
        new Dt("20041019T100000", true),
        new Dt("20041019T180000", true),
        new Dt("20041019T180000", true),
        new Dt("20051024T183000", true),
        new Dt("20041013T090000", true),
        new Dt("20041013T160000", true),
        new Dt("20041015T133000", true),
        new Dt("20041012T120000", true),
        new Dt("20041016T000000", true),
        new Dt("20041103T150000", false),
        new Dt("20041117T150000", false),
        new Dt("20041019T160000", true),
        new Dt("20041019T113000", true),
        new Dt("20041111T160000", false),
        new Dt("20041118T160000", false),
        new Dt("20041018T190000", true),
        new Dt("20041116T180000", false),
        new Dt("20041028T180000", true),
        new Dt("20041202T180000", false),
        new Dt("20041020T120000", true),
        new Dt("20041022T103000", true),
        new Dt("20041104T193000", false),
        new Dt("20041022T160000", true),
        new Dt("20041021T190000", true),
        new Dt("20041021T180000", true),
        new Dt("20041021T180000", true),
        new Dt("20041020T160000", true),
        new Dt("20041025T183000", true),
        new Dt("20041025T180000", true),
        new Dt("20041025T190000", true),
        new Dt("20041025T180000", true),
        new Dt("20041025T190000", true),
        new Dt("20041021T160000", true),
        new Dt("20041027T160000", true),
        new Dt("20041101T160000", false),
        new Dt("20041103T160000", false),
        new Dt("20041117T160000", false),
        new Dt("20041201T160000", false),
        new Dt("20041102T200000", false),
        new Dt("20051101T190000", false),
        new Dt("20041109T180000", false),
        new Dt("20041026T153000", true),
        new Dt("20041205T130000", false),
        new Dt("20041025T180000", true),
        new Dt("20041029T183000", true),
        new Dt("20041027T120000", true),
        new Dt("20041112T170000", false),
        new Dt("20041117T113000", false),
        new Dt("20041214T113000", false),
        new Dt("20041209T130000", false),
        new Dt("20041028T060000", true),
        new Dt("20041031T180000", true),
        new Dt("20041101T180000", false),
        new Dt("20041102T190000", false),
        new Dt("20041103T200000", false),
        new Dt("20041104T200000", false),
        new Dt("20041106T200000", false),
        new Dt("20041105T200000", false),
        new Dt("20041026T180000", true),
        new Dt("20041026T180000", true),
        new Dt("20041026T180000", true),
        new Dt("20041027T170000", true),
        new Dt("20041027T180000", true),
        new Dt("20041027T160000", true),
        new Dt("20041027T120000", true),
        new Dt("20041029T190000", true),
        new Dt("20041030T190000", true),
        new Dt("20041105T190000", false),
        new Dt("20041106T190000", false),
        new Dt("20041112T190000", false),
        new Dt("20041113T190000", false),
        new Dt("20041117T190000", false),
        new Dt("20041120T190000", false),
        new Dt("20041203T190000", false),
        new Dt("20041204T190000", false),
        new Dt("20041210T190000", false),
        new Dt("20041211T190000", false),
        new Dt("20041110T190000", false),
        new Dt("20041119T190000", false),
        new Dt("20041029T150000", true),
        new Dt("20041104T040000", false),
        new Dt("20041111T040000", false),
        new Dt("20041118T040000", false),
        new Dt("20050105T080000", false),
        new Dt("20050113T180000", false),
        new Dt("20041103T100000", false),
        new Dt("20041109T140000", false),
        new Dt("20041116T150000", false),
        new Dt("20041117T083000", false),
        new Dt("20041116T150000", false),
        new Dt("20041108T180000", false),
        new Dt("20041108T180000", false),
        new Dt("20051020T190000", true),
        new Dt("20041109T120000", false),
        new Dt("20041110T180000", false),
        new Dt("20041111T180000", false),
        new Dt("20041105T110000", false),
        new Dt("20041112T110000", false),
        new Dt("20041105T110000", false),
        new Dt("20041106T130000", false),
        new Dt("20041112T163000", false),
        new Dt("20041113T100000", false),
        new Dt("20041118T191000", false),
        new Dt("20041115T160000", false),
        new Dt("20041117T163000", false),
        new Dt("20041114T100000", false),
        new Dt("20041114T100000", false),
        new Dt("20041216T040000", false),
        new Dt("20041130T160000", false),
        new Dt("20041117T170000", false),
        new Dt("20041117T140000", false),
        new Dt("20041119T070000", false),
        new Dt("20041117T070000", false),
        new Dt("20041201T090000", false),
        new Dt("20041201T040000", false),
        new Dt("20050115T183000", false),
        new Dt("20050625T190500", true),
        new Dt("20041204T200000", false),
        new Dt("20041202T160000", false),
        new Dt("20041209T160000", false),
        new Dt("20041202T100000", false),
        new Dt("20050406T160000", true),
        new Dt("20050519T110000", true),
        new Dt("20050216T180000", false),
        new Dt("20041201T160000", false),
        new Dt("20041204T190000", false),
        new Dt("20041130T180000", false),
        new Dt("20041124T090000", false),
        new Dt("20041202T140000", false),
        new Dt("20041206T073000", false),
        new Dt("20041214T150000", false),
        new Dt("20041203T033000", false),
        new Dt("20041208T170000", false),
        new Dt("20041207T143000", false),
        new Dt("20041205T150000", false),
        new Dt("20050226T103000", false),
        new Dt("20050323T170000", true),
        new Dt("20050416T090000", true),
        new Dt("20050604T130000", true),
        new Dt("20050717T133500", true),
        new Dt("20050820T170000", true),
        new Dt("20041207T153000", false),
        new Dt("20041209T160000", false),
        new Dt("20041213T150000", false),
        new Dt("20050106T180000", false),
        new Dt("20050224T160000", false),
        new Dt("20050414T070000", true),
        new Dt("20050117T163000", false),
        new Dt("20050117T170000", false),
        new Dt("20050117T180000", false),
        new Dt("20050118T180000", false),
        new Dt("20050119T183000", false),
        new Dt("20050119T200000", false),
        new Dt("20050120T200000", false),
        new Dt("20050121T190000", false),
        new Dt("20050122T100000", false),
        new Dt("20050122T200000", false),
        new Dt("20050413T160000", true),
        new Dt("20050309T173000", true),
        new Dt("20050212T093000", false),
        new Dt("20050126T190000", false),
        new Dt("20050128T210000", false),
        new Dt("20050207T183000", false),
        new Dt("20050217T190000", false),
        new Dt("20050126T170000", false),
        new Dt("20050216T170000", false),
        new Dt("20050309T170000", true),
        new Dt("20050323T170000", true),
        new Dt("20050406T170000", true),
        new Dt("20050420T170000", true),
        new Dt("20060201T173000", false),
        new Dt("20050108T163000", false),
        new Dt("20050111T183000", false),
        new Dt("20050215T113000", false),
        new Dt("20050121T103000", false),
        new Dt("20050419T113000", true),
        new Dt("20050331T130000", true),
        new Dt("20050330T113000", true),
        new Dt("20050121T200000", false),
        new Dt("20050128T200000", false),
        new Dt("20050204T200000", false),
        new Dt("20050330T200000", true),
        new Dt("20050413T200000", true),
        new Dt("20050427T200000", true),
        new Dt("20050511T200000", true),
        new Dt("20050525T200000", true),
        new Dt("20050408T190000", true),
        new Dt("20050402T200000", true),
        new Dt("20050216T171500", false),
        new Dt("20050223T171500", false),
        new Dt("20050302T171500", true),
        new Dt("20050309T171500", true),
        new Dt("20050316T171500", true),
        new Dt("20050105T190000", false),
        new Dt("20050216T171500", false),
        new Dt("20050407T173000", true),
        new Dt("20050226T063000", false),
        new Dt("20050107T083000", false),
        new Dt("20050110T083000", false),
        new Dt("20050112T083000", false),
        new Dt("20050106T090000", false),
        new Dt("20050107T090000", false),
        new Dt("20050111T090000", false),
        new Dt("20050112T083000", false),
        new Dt("20050113T090000", false),
        new Dt("20050114T090000", false),
        new Dt("20050118T090000", false),
        new Dt("20050119T083000", false),
        new Dt("20050120T090000", false),
        new Dt("20050121T090000", false),
        new Dt("20050126T090000", false),
        new Dt("20050208T090000", false),
        new Dt("20050209T083000", false),
        new Dt("20050211T090000", false),
        new Dt("20050215T090000", false),
        new Dt("20050216T083000", false),
        new Dt("20050217T100000", false),
        new Dt("20050218T090000", false),
        new Dt("20050222T090000", false),
        new Dt("20050223T090000", false),
        new Dt("20050224T090000", false),
        new Dt("20050105T073000", false),
        new Dt("20050118T160000", false),
        new Dt("20050125T160000", false),
        new Dt("20050127T160000", false),
        new Dt("20050218T164500", false),
        new Dt("20050110T180000", false),
        new Dt("20050209T110000", false),
        new Dt("20050212T163000", false),
        new Dt("20050212T190000", false),
        new Dt("20050409T120000", true),
        new Dt("20050128T103000", false),
        new Dt("20050111T210000", false),
        new Dt("20050401T090000", true),
        new Dt("20051022T090000", true),
        new Dt("20050402T083000", true),
        new Dt("20050125T160000", false),
        new Dt("20050114T073000", false),
        new Dt("20050121T200000", false),
        new Dt("20050128T200000", false),
        new Dt("20050204T200000", false),
        new Dt("20050131T181500", false),
        new Dt("20050307T180000", true),
        new Dt("20050205T200000", false),
        new Dt("20050211T200000", false),
        new Dt("20050225T200000", false),
        new Dt("20050401T200000", true),
        new Dt("20050408T200000", true),
        new Dt("20050415T200000", true),
        new Dt("20050422T200000", true),
        new Dt("20050429T200000", true),
        new Dt("20050120T143000", false),
        new Dt("20050124T160000", false),
        new Dt("20051121T160000", false),
        new Dt("20050228T160000", false),
        new Dt("20051205T160000", false),
        new Dt("20050321T160000", true),
        new Dt("20051107T160000", false),
        new Dt("20050404T160000", true),
        new Dt("20050411T160000", true),
        new Dt("20050418T160000", true),
        new Dt("20050425T160000", true),
        new Dt("20050502T160000", true),
        new Dt("20050201T160000", false),
        new Dt("20050301T160000", true),
        new Dt("20050308T160000", true),
        new Dt("20050215T160000", false),
        new Dt("20050120T160000", false),
        new Dt("20050127T160000", false),
        new Dt("20050119T130000", false),
        new Dt("20050127T120000", false),
        new Dt("20050120T170000", false),
        new Dt("20050128T140000", false),
        new Dt("20050121T130000", false),
        new Dt("20050127T120000", false),
        new Dt("20050119T160000", false),
        new Dt("20050119T180000", false),
        new Dt("20050121T120000", false),
        new Dt("20050121T160000", false),
        new Dt("20050124T190000", false),
        new Dt("20050125T130000", false),
        new Dt("20050125T130000", false),
        new Dt("20050131T170000", false),
        new Dt("20050124T170000", false),
        new Dt("20050126T120000", false),
        new Dt("20050204T140000", false),
        new Dt("20050125T140000", false),
        new Dt("20050201T150000", false),
        new Dt("20050217T120000", false),
        new Dt("20050201T180000", false),
        new Dt("20050307T150000", true),
        new Dt("20050202T170000", false),
        new Dt("20050201T090000", false),
        new Dt("20050203T090000", false),
        new Dt("20050223T120000", false),
        new Dt("20050204T090000", false),
        new Dt("20050124T160000", false),
        new Dt("20050126T160000", false),
        new Dt("20050202T160000", false),
        new Dt("20050209T160000", false),
        new Dt("20050223T160000", false),
        new Dt("20050309T160000", true),
        new Dt("20050301T180000", true),
        new Dt("20050420T160000", true),
        new Dt("20050120T120000", false),
        new Dt("20051114T160000", false),
        new Dt("20050126T153000", false),
        new Dt("20050215T160000", false),
        new Dt("20050308T160000", true),
        new Dt("20050309T153000", true),
        new Dt("20050315T193000", true),
        new Dt("20050323T153000", true),
        new Dt("20050329T193000", true),
        new Dt("20050204T103000", false),
        new Dt("20050201T160000", false),
        new Dt("20050224T100000", false),
        new Dt("20050226T063000", false),
        new Dt("20050204T160000", false),
        new Dt("20050211T103000", false),
        new Dt("20050218T103000", false),
        new Dt("20050304T103000", true),
        new Dt("20050401T103000", true),
        new Dt("20050415T103000", true),
        new Dt("20050422T103000", true),
        new Dt("20050429T103000", true),
        new Dt("20050215T160000", false),
        new Dt("20050325T160000", true),
        new Dt("20050208T150000", false),
        new Dt("20050211T120000", false),
        new Dt("20050307T160000", true),
        new Dt("20050418T160000", true),
        new Dt("20050411T160000", true),
        new Dt("20050208T160000", false),
        new Dt("20050201T151500", false),
        new Dt("20050210T160000", false),
        new Dt("20050217T160000", false),
        new Dt("20050224T160000", false),
        new Dt("20050205T010000", false),
        new Dt("20050225T193000", false),
        new Dt("20050405T183000", true),
        new Dt("20050215T150000", false),
        new Dt("20050504T180000", true),
        new Dt("20050216T200000", false),
        new Dt("20050228T190000", false),
        new Dt("20050307T190000", true),
        new Dt("20050321T190000", true),
        new Dt("20050204T180000", false),
        new Dt("20050212T100000", false),
        new Dt("20050206T183000", false),
        new Dt("20050211T170000", false),
        new Dt("20050405T150000", true),
        new Dt("20050223T140000", false),
        new Dt("20050301T150000", true),
        new Dt("20050207T140000", false),
        new Dt("20050207T160000", false),
        new Dt("20050210T160000", false),
        new Dt("20050209T160000", false),
        new Dt("20050209T153000", false),
        new Dt("20050323T180000", true),
        new Dt("20050215T160000", false),
        new Dt("20050209T073000", false),
        new Dt("20050310T180000", true),
        new Dt("20050208T090000", false),
        new Dt("20050209T090000", false),
        new Dt("20050210T090000", false),
        new Dt("20050211T090000", false),
        new Dt("20050214T090000", false),
        new Dt("20050215T090000", false),
        new Dt("20050216T090000", false),
        new Dt("20050217T090000", false),
        new Dt("20050218T090000", false),
        new Dt("20050222T090000", false),
        new Dt("20050223T090000", false),
        new Dt("20050224T090000", false),
        new Dt("20050225T090000", false),
        new Dt("20050228T090000", false),
        new Dt("20050301T090000", true),
        new Dt("20050302T090000", true),
        new Dt("20050303T090000", true),
        new Dt("20051003T090000", true),
        new Dt("20050307T090000", true),
        new Dt("20050309T090000", true),
        new Dt("20050310T090000", true),
        new Dt("20050311T090000", true),
        new Dt("20050308T090000", true),
        new Dt("20050331T193000", true),
        new Dt("20050214T100000", false),
        new Dt("20050213T120000", false),
        new Dt("20050217T190000", false),
        new Dt("20050210T190000", false),
        new Dt("20050225T190000", false),
        new Dt("20050210T180000", false),
        new Dt("20050222T100000", false),
        new Dt("20050211T113000", false),
        new Dt("20051025T183000", true),
        new Dt("20050216T180000", false),
        new Dt("20050216T180000", false),
        new Dt("20050216T190000", false),
        new Dt("20050216T180000", false),
        new Dt("20050217T170000", false),
        new Dt("20051101T183000", false),
        new Dt("20050222T180000", false),
        new Dt("20050216T180000", false),
        new Dt("20050217T180000", false),
        new Dt("20050223T180000", false),
        new Dt("20050302T183000", true),
        new Dt("20050330T180000", true),
        new Dt("20050406T180000", true),
        new Dt("20050413T180000", true),
        new Dt("20050216T143000", false),
        new Dt("20050214T110000", false),
        new Dt("20050215T200000", false),
        new Dt("20050226T120000", false),
        new Dt("20050223T160000", false),
        new Dt("20050223T180000", false),
        new Dt("20050228T180000", false),
        new Dt("20050309T120000", true),
        new Dt("20050409T090000", true),
        new Dt("20050910T090000", true),
        new Dt("20051104T090000", false),
        new Dt("20050308T160000", true),
        new Dt("20050331T160000", true),
        new Dt("20050228T160000", false),
        new Dt("20050404T160000", true),
        new Dt("20050216T230000", false),
        new Dt("20050227T170000", false),
        new Dt("20050223T180000", false),
        new Dt("20050221T100000", false),
        new Dt("20050303T150000", true),
        new Dt("20050311T190000", true),
        new Dt("20050326T130000", true),
        new Dt("20050301T150000", true),
        new Dt("20050713T123000", true),
        new Dt("20050808T080000", true),
        new Dt("20050308T183000", true),
        new Dt("20050316T183000", true),
        new Dt("20050331T023000", true),
        new Dt("20050325T103000", true),
        new Dt("20050309T183000", true),
        new Dt("20050408T103000", true),
        new Dt("20050228T160000", false),
        new Dt("20050307T160000", true),
        new Dt("20050310T160000", true),
        new Dt("20050329T160000", true),
        new Dt("20050303T160000", true),
        new Dt("20050310T160000", true),
        new Dt("20050324T160000", true),
        new Dt("20050331T160000", true),
        new Dt("20050311T120000", true),
        new Dt("20050228T110000", false),
        new Dt("20050228T160000", false),
        new Dt("20050303T090000", true),
        new Dt("20050304T090000", true),
        new Dt("20050308T090000", true),
        new Dt("20050309T083000", true),
        new Dt("20050310T090000", true),
        new Dt("20050315T090000", true),
        new Dt("20050316T083000", true),
        new Dt("20050318T090000", true),
        new Dt("20050322T090000", true),
        new Dt("20050324T090000", true),
        new Dt("20050329T090000", true),
        new Dt("20050330T090000", true),
        new Dt("20050401T090000", true),
        new Dt("20050427T180000", true),
        new Dt("20050312T100000", true),
        new Dt("20050302T180000", true),
        new Dt("20050331T180000", true),
        new Dt("20050411T140000", true),
        new Dt("20050412T150000", true),
        new Dt("20050419T090000", true),
        new Dt("20050420T083000", true),
        new Dt("20050421T090000", true),
        new Dt("20050422T090000", true),
        new Dt("20050426T090000", true),
        new Dt("20050428T090000", true),
        new Dt("20050328T160000", true),
        new Dt("20050322T160000", true),
        new Dt("20050324T160000", true),
        new Dt("20050306T160000", true),
        new Dt("20050302T180000", true),
        new Dt("20050302T180000", true),
        new Dt("20050303T180000", true),
        new Dt("20050308T150000", true),
        new Dt("20050311T103000", true),
        new Dt("20050307T180000", true),
        new Dt("20050308T180000", true),
        new Dt("20050308T180000", true),
        new Dt("20050309T190000", true),
        new Dt("20050308T110000", true),
        new Dt("20050309T160000", true),
        new Dt("20050310T150000", true),
        new Dt("20050309T120000", true),
        new Dt("20050308T153000", true),
        new Dt("20050308T100000", true),
        new Dt("20050310T161000", true),
        new Dt("20050323T020000", true),
        new Dt("20050323T113000", true),
        new Dt("20050723T000000", true),
        new Dt("20050401T113000", true),
        new Dt("20050311T100000", true),
        new Dt("20050324T180000", true),
        new Dt("20050404T140000", true),
        new Dt("20050504T180000", true),
        new Dt("20050330T183000", true),
        new Dt("20050405T180000", true),
        new Dt("20050521T120000", true),
        new Dt("20050316T183000", true),
        new Dt("20050619T000000", true),
        new Dt("20050313T183000", true),
        new Dt("20050505T180000", true),
        new Dt("20050611T000000", true),
        new Dt("20050418T150000", true),
        new Dt("20050429T170000", true),
        new Dt("20050430T100000", true),
        new Dt("20050321T150000", true),
        new Dt("20050330T120000", true),
        new Dt("20050322T150000", true),
        new Dt("20050329T150000", true),
        new Dt("20050321T140000", true),
        new Dt("20050328T140000", true),
        new Dt("20050408T200000", true),
        new Dt("20050409T200000", true),
        new Dt("20050414T200000", true),
        new Dt("20050415T200000", true),
        new Dt("20050410T140000", true),
        new Dt("20050516T080000", true),
        new Dt("20050323T180000", true),
        new Dt("20050321T100000", true),
        new Dt("20050322T180000", true),
        new Dt("20050323T180000", true),
        new Dt("20050324T100000", true),
        new Dt("20050324T180000", true),
        new Dt("20050322T190000", true),
        new Dt("20050322T090000", true),
        new Dt("20050323T180000", true),
        new Dt("20050323T100000", true),
        new Dt("20050323T100000", true),
        new Dt("20050329T110000", true),
        new Dt("20050324T190000", true),
        new Dt("20050330T193000", true),
        new Dt("20050416T200000", true),
        new Dt("20050406T193000", true),
        new Dt("20050420T193000", true),
        new Dt("20050407T160000", true),
        new Dt("20050414T160000", true),
        new Dt("20050329T090000", true),
        new Dt("20050421T160000", true),
        new Dt("20050428T160000", true),
        new Dt("20050328T160000", true),
        new Dt("20050404T140000", true),
        new Dt("20050409T180000", true),
        new Dt("20050409T130000", true),
        new Dt("20050408T120000", true),
        new Dt("20050411T153000", true),
        new Dt("20050404T160000", true),
        new Dt("20050407T160000", true),
        new Dt("20050405T160000", true),
        new Dt("20050412T160000", true),
        new Dt("20050419T160000", true),
        new Dt("20050426T160000", true),
        new Dt("20050405T073000", true),
        new Dt("20050406T180000", true),
        new Dt("20050412T160000", true),
        new Dt("20050405T100000", true),
        new Dt("20050406T160000", true),
        new Dt("20050406T170000", true),
        new Dt("20050412T160000", true),
        new Dt("20050428T200000", true),
        new Dt("20050429T200000", true),
        new Dt("20050408T070000", true),
        new Dt("20050503T080000", true),
        new Dt("20050503T190000", true),
        new Dt("20050408T223000", true),
        new Dt("20050516T180000", true),
        new Dt("20050407T120000", true),
        new Dt("20050413T140000", true),
        new Dt("20050420T113000", true),
        new Dt("20050422T120000", true),
        new Dt("20050413T160000", true),
        new Dt("20050415T153000", true),
        new Dt("20050413T120000", true),
        new Dt("20050412T100000", true),
        new Dt("20050412T153000", true),
        new Dt("20050411T160000", true),
        new Dt("20050412T160000", true),
        new Dt("20050413T190000", true),
        new Dt("20050418T140000", true),
        new Dt("20050511T190000", true),
        new Dt("20050418T180000", true),
        new Dt("20050420T183000", true),
        new Dt("20050419T094500", true),
        new Dt("20050426T180000", true),
        new Dt("20050512T180000", true),
        new Dt("20050525T180000", true),
        new Dt("20050421T180000", true),
        new Dt("20050419T220000", true),
        new Dt("20050420T093000", true),
        new Dt("20050426T050000", true),
        new Dt("20050425T140000", true),
        new Dt("20050425T150000", true),
        new Dt("20050423T140000", true),
        new Dt("20050429T090000", true),
        new Dt("20050429T160000", true),
        new Dt("20050421T220000", true),
        new Dt("20050428T140000", true),
        new Dt("20050501T133000", true),
        new Dt("20050522T120000", true),
        new Dt("20050524T160000", true),
        new Dt("20050525T160000", true),
        new Dt("20050427T160000", true),
        new Dt("20050507T180000", true),
        new Dt("20050503T153000", true),
        new Dt("20050508T160000", true),
        new Dt("20050430T190000", true),
        new Dt("20050506T193000", true),
        new Dt("20050430T193000", true),
        new Dt("20050428T160000", true),
        new Dt("20050428T193000", true),
        new Dt("20050502T140000", true),
        new Dt("20050520T160000", true),
        new Dt("20050506T200000", true),
        new Dt("20050503T080000", true),
        new Dt("20050504T160000", true),
        new Dt("20050607T110000", true),
        new Dt("20050519T083000", true),
        new Dt("20050517T120000", true),
        new Dt("20050506T073000", true),
        new Dt("20050511T090000", true),
        new Dt("20050512T090000", true),
        new Dt("20050513T083000", true),
        new Dt("20050518T120000", true),
        new Dt("20050519T090000", true),
        new Dt("20050520T090000", true),
        new Dt("20050524T090000", true),
        new Dt("20050525T090000", true),
        new Dt("20050526T090000", true),
        new Dt("20050527T090000", true),
        new Dt("20050531T090000", true),
        new Dt("20050608T090000", true),
        new Dt("20050609T090000", true),
        new Dt("20050610T120000", true),
        new Dt("20050621T090000", true),
        new Dt("20050623T090000", true),
        new Dt("20050624T120000", true),
        new Dt("20050628T100000", true),
        new Dt("20050629T090000", true),
        new Dt("20050707T090000", true),
        new Dt("20050708T120000", true),
        new Dt("20050720T090000", true),
        new Dt("20050721T090000", true),
        new Dt("20050722T090000", true),
        new Dt("20050726T090000", true),
        new Dt("20050727T120000", true),
        new Dt("20050728T090000", true),
        new Dt("20050729T090000", true),
        new Dt("20050810T090000", true),
        new Dt("20050812T120000", true),
        new Dt("20050816T090000", true),
        new Dt("20050818T120000", true),
        new Dt("20050819T090000", true),
        new Dt("20050825T090000", true),
        new Dt("20050826T090000", true),
        new Dt("20050830T090000", true),
        new Dt("20050512T190000", true),
        new Dt("20050521T130000", true),
        new Dt("20050519T183000", true),
        new Dt("20050526T180000", true),
        new Dt("20050605T163000", true),
        new Dt("20050524T160000", true),
        new Dt("20050525T160000", true),
        new Dt("20050604T000000", true),
        new Dt("20050524T180000", true),
        new Dt("20060331T090000", true),
        new Dt("20060408T084500", true),
        new Dt("20050523T160000", true),
        new Dt("20050518T160000", true),
        new Dt("20050531T090000", true),
        new Dt("20050613T100000", true),
        new Dt("20050930T100000", true),
        new Dt("20050910T130000", true),
        new Dt("20050917T130000", true),
        new Dt("20050722T190000", true),
        new Dt("20050901T180000", true),
        new Dt("20051015T110000", true),
        new Dt("20050601T071500", true),
        new Dt("20050621T183000", true),
        new Dt("20050628T073000", true),
        new Dt("20050608T090000", true),
        new Dt("20050905T120000", true),
        new Dt("20050909T200000", true),
        new Dt("20050910T210000", true),
        new Dt("20050916T200000", true),
        new Dt("20051107T193000", false),
        new Dt("20051112T193000", false),
        new Dt("20051007T030000", true),
        new Dt("20050916T200000", true),
        new Dt("20050917T193000", true),
        new Dt("20050917T193000", true),
        new Dt("20050923T190000", true),
        new Dt("20050923T200000", true),
        new Dt("20050924T180000", true),
        new Dt("20050930T190000", true),
        new Dt("20050930T200000", true),
        new Dt("20050917T083000", true),
        new Dt("20051008T200000", true),
        new Dt("20051001T100000", true),
        new Dt("20051024T160000", true),
        new Dt("20050924T083000", true),
        new Dt("20050924T200000", true),
        new Dt("20051104T210000", false),
        new Dt("20051104T200000", false),
        new Dt("20051105T200000", false),
        new Dt("20051105T200000", false),
        new Dt("20060105T180000", false),
        new Dt("20051112T190000", false),
        new Dt("20051118T200000", false),
        new Dt("20051119T220000", false),
        new Dt("20051119T190000", false),
        new Dt("20051202T200000", false),
        new Dt("20051203T200000", false),
        new Dt("20051212T120000", false),
        new Dt("20051209T200000", false),
        new Dt("20051210T200000", false),
        new Dt("20051014T180000", true),
        new Dt("20051015T160000", true),
        new Dt("20051021T210000", true),
        new Dt("20051022T200000", true),
        new Dt("20051028T190000", true),
        new Dt("20051029T200000", true),
        new Dt("20051021T200000", true),
        new Dt("20050628T113000", true),
        new Dt("20050712T113000", true),
        new Dt("20050726T113000", true),
        new Dt("20050719T113000", true),
        new Dt("20050626T220000", true),
        new Dt("20050717T220000", true),
        new Dt("20050803T193000", true),
        new Dt("20050714T210000", true),
        new Dt("20050803T210000", true),
        new Dt("20050806T193000", true),
        new Dt("20050805T193000", true),
        new Dt("20050804T193000", true),
        new Dt("20050919T093000", true),
        new Dt("20050621T203000", true),
        new Dt("20050908T183000", true),
        new Dt("20050826T200000", true),
        new Dt("20050914T200000", true),
        new Dt("20050919T200000", true),
        new Dt("20050923T200000", true),
        new Dt("20050827T183000", true),
        new Dt("20051007T200000", true),
        new Dt("20051031T220000", true),
        new Dt("20051105T200000", false),
        new Dt("20051109T200000", false),
        new Dt("20051118T190000", false),
        new Dt("20051130T190000", false),
        new Dt("20051204T190000", false),
        new Dt("20051214T190000", false),
        new Dt("20050628T153500", true),
        new Dt("20050907T160000", true),
        new Dt("20050910T130000", true),
        new Dt("20050915T190000", true),
        new Dt("20051127T110500", false),
        new Dt("20051128T110500", false),
        new Dt("20060116T140000", false),
        new Dt("20060127T140500", false),
        new Dt("20060504T090000", true),
        new Dt("20060521T110000", true),
        new Dt("20051111T160000", false),
        new Dt("20050807T130000", true),
        new Dt("20051015T150000", true),
        new Dt("20050928T160000", true),
        new Dt("20051007T150000", true),
        new Dt("20051008T130000", true),
        new Dt("20051012T160000", true),
        new Dt("20051015T130000", true),
        new Dt("20051017T160000", true),
        new Dt("20051008T130000", true),
        new Dt("20051022T140000", true),
        new Dt("20051105T130000", false),
        new Dt("20050903T170000", true),
        new Dt("20050903T193000", true),
        new Dt("20050904T120000", true),
        new Dt("20050904T143000", true),
        new Dt("20050923T160000", true),
        new Dt("20050924T140000", true),
        new Dt("20050928T190000", true),
        new Dt("20051012T190000", true),
        new Dt("20051016T150000", true),
        new Dt("20051029T150000", true),
        new Dt("20050906T190000", true),
        new Dt("20051001T160000", true),
        new Dt("20051007T180000", true),
        new Dt("20051008T160000", true),
        new Dt("20051011T190000", true),
        new Dt("20051021T160000", true),
        new Dt("20051022T140000", true),
        new Dt("20050903T093000", true),
        new Dt("20050917T140000", true),
        new Dt("20050927T160000", true),
        new Dt("20051001T140000", true),
        new Dt("20051004T153000", true),
        new Dt("20051127T140000", false),
        new Dt("20051206T190000", false),
        new Dt("20060106T190000", false),
        new Dt("20060117T200000", false),
        new Dt("20060120T200000", false),
        new Dt("20060121T160000", false),
        new Dt("20060210T200000", false),
        new Dt("20060211T160000", false),
        new Dt("20060217T200000", false),
        new Dt("20060218T160000", false),
        new Dt("20051129T200000", false),
        new Dt("20051203T170000", false),
        new Dt("20060104T180000", false),
        new Dt("20060108T140000", false),
        new Dt("20060117T180000", false),
        new Dt("20060120T180000", false),
        new Dt("20060121T140000", false),
        new Dt("20060210T180000", false),
        new Dt("20060211T140000", false),
        new Dt("20060217T180000", false),
        new Dt("20060218T140000", false),
        new Dt("20051007T190000", true),
        new Dt("20050713T230000", true),
        new Dt("20050727T193000", true),
        new Dt("20050714T233000", true),
        new Dt("20050731T200000", true),
        new Dt("20050806T140000", true),
        new Dt("20050719T080000", true),
        new Dt("20050719T233000", true),
        new Dt("20050830T163000", true),
        new Dt("20050920T163000", true),
        new Dt("20050725T170000", true),
        new Dt("20050811T130000", true),
        new Dt("20050913T113000", true),
        new Dt("20051110T113000", false),
        new Dt("20051207T113000", false),
        new Dt("20051012T113000", true),
        new Dt("20060124T113000", false),
        new Dt("20060222T113000", false),
        new Dt("20060328T113000", true),
        new Dt("20050912T160000", true),
        new Dt("20060420T113000", true),
        new Dt("20060525T113000", true),
        new Dt("20060628T113000", true),
        new Dt("20050826T173000", true),
        new Dt("20050831T110000", true),
        new Dt("20050911T110000", true),
        new Dt("20051001T100000", true),
        new Dt("20051105T100000", false),
        new Dt("20051204T100000", false),
        new Dt("20060121T100000", false),
        new Dt("20060211T100000", false),
        new Dt("20060325T100000", true),
        new Dt("20060419T100000", true),
        new Dt("20060504T053000", true),
        new Dt("20060505T053000", true),
        new Dt("20060308T170000", true),
        new Dt("20060111T040000", false),
        new Dt("20060127T200000", false),
        new Dt("20060120T200000", false),
        new Dt("20050729T193000", true),
        new Dt("20050730T193000", true),
        new Dt("20050909T220000", true),
        new Dt("20051007T200000", true),
        new Dt("20050805T200000", true),
        new Dt("20050807T200000", true),
        new Dt("20050804T200000", true),
        new Dt("20050806T200000", true),
        new Dt("20050810T200000", true),
        new Dt("20050811T200000", true),
        new Dt("20050812T200000", true),
        new Dt("20050813T200000", true),
        new Dt("20050823T043000", true),
        new Dt("20050728T050000", true),
        new Dt("20050802T050000", true),
        new Dt("20050804T050000", true),
        new Dt("20050809T050000", true),
        new Dt("20060201T180000", false),
        new Dt("20060217T200000", false),
        new Dt("20060215T170000", false),
        new Dt("20060322T180000", true),
        new Dt("20060329T180000", true),
        new Dt("20060405T180000", true),
        new Dt("20060217T103000", false),
        new Dt("20060503T200000", true),
        new Dt("20060510T200000", true),
        new Dt("20060517T200000", true),
        new Dt("20060524T200000", true),
        new Dt("20050921T193000", true),
        new Dt("20051026T193000", true),
        new Dt("20051129T190000", false),
        new Dt("20050817T130000", true),
        new Dt("20051023T140000", true),
        new Dt("20051028T190000", true),
        new Dt("20051029T190000", true),
        new Dt("20051111T190000", false),
        new Dt("20051112T190000", false),
        new Dt("20051125T160000", false),
        new Dt("20051202T190000", false),
        new Dt("20051210T190000", false),
        new Dt("20060106T190000", false),
        new Dt("20060107T190000", false),
        new Dt("20060113T190000", false),
        new Dt("20060114T190000", false),
        new Dt("20060204T190000", false),
        new Dt("20060210T190000", false),
        new Dt("20060211T120000", false),
        new Dt("20060211T190000", false),
        new Dt("20060224T190000", false),
        new Dt("20060225T190000", false),
        new Dt("20051001T130000", true),
        new Dt("20050918T130000", true),
        new Dt("20050925T120000", true),
        new Dt("20051008T190000", true),
        new Dt("20051009T140000", true),
        new Dt("20051015T190000", true),
        new Dt("20051029T150000", true),
        new Dt("20051104T190000", false),
        new Dt("20051105T160000", false),
        new Dt("20051112T140000", false),
        new Dt("20051204T140000", false),
        new Dt("20060106T143000", false),
        new Dt("20060107T143000", false),
        new Dt("20060212T150000", false),
        new Dt("20060214T190000", false),
        new Dt("20050218T160000", false),
        new Dt("20060219T140000", false),
        new Dt("20060401T160000", true),
        new Dt("20060421T160000", true),
        new Dt("20060422T140000", true),
        new Dt("20060402T130000", true),
        new Dt("20060311T130000", true),
        new Dt("20060325T130000", true),
        new Dt("20060404T160000", true),
        new Dt("20060408T130000", true),
        new Dt("20060415T140000", true),
        new Dt("20060426T160000", true),
        new Dt("20060429T130000", true),
        new Dt("20050824T233000", true),
        new Dt("20050825T160000", true),
        new Dt("20060211T090000", false),
        new Dt("20050824T153000", true),
        new Dt("20050823T130000", true),
        new Dt("20050825T130000", true),
        new Dt("20050824T100000", true),
        new Dt("20050831T100000", true),
        new Dt("20050914T193000", true),
        new Dt("20050919T160000", true),
        new Dt("20051005T120000", true),
        new Dt("20051012T120000", true),
        new Dt("20050911T170000", true),
        new Dt("20050914T120000", true),
        new Dt("20050914T160000", true),
        new Dt("20050928T135500", true),
        new Dt("20050824T210000", true),
        new Dt("20050915T153000", true),
        new Dt("20050908T090000", true),
        new Dt("20050909T090000", true),
        new Dt("20050913T090000", true),
        new Dt("20050914T110000", true),
        new Dt("20050915T090000", true),
        new Dt("20050916T090000", true),
        new Dt("20050920T090000", true),
        new Dt("20050921T110000", true),
        new Dt("20050922T090000", true),
        new Dt("20050923T090000", true),
        new Dt("20050927T090000", true),
        new Dt("20050928T090000", true),
        new Dt("20050929T160000", true),
        new Dt("20051018T160000", true),
        new Dt("20051011T090000", true),
        new Dt("20051012T110000", true),
        new Dt("20051013T090000", true),
        new Dt("20051018T090000", true),
        new Dt("20051019T110000", true),
        new Dt("20051020T090000", true),
        new Dt("20051021T090000", true),
        new Dt("20051023T090000", true),
        new Dt("20050828T070000", true),
        new Dt("20050915T193000", true),
        new Dt("20051013T193000", true),
        new Dt("20051210T153000", false),
        new Dt("20050830T153000", true),
        new Dt("20050928T173000", true),
        new Dt("20051010T090000", true),
        new Dt("20051017T090000", true),
        new Dt("20051031T090000", true),
        new Dt("20051024T090000", true),
        new Dt("20051118T044500", false),
        new Dt("20051107T090000", false),
        new Dt("20050921T183000", true),
        new Dt("20050902T103000", true),
        new Dt("20050914T140000", true),
        new Dt("20050921T140000", true),
        new Dt("20050928T140000", true),
        new Dt("20051012T140000", true),
        new Dt("20051019T140000", true),
        new Dt("20051026T140000", true),
        new Dt("20051102T140000", false),
        new Dt("20051026T170000", true),
        new Dt("20051116T170000", false),
        new Dt("20050913T153000", true),
        new Dt("20060208T170000", false),
        new Dt("20051207T170000", false),
        new Dt("20060405T080000", true),
        new Dt("20060503T180000", true),
        new Dt("20050907T093000", true),
        new Dt("20050914T093000", true),
        new Dt("20051116T093000", false),
        new Dt("20051109T093000", false),
        new Dt("20051130T093000", false),
        new Dt("20051207T093000", false),
        new Dt("20051006T100000", true),
        new Dt("20051007T093000", true),
        new Dt("20050909T103000", true),
        new Dt("20050911T083000", true),
        new Dt("20050914T160000", true),
        new Dt("20050903T130000", true),
        new Dt("20050916T103000", true),
        new Dt("20050923T103000", true),
        new Dt("20050930T103000", true),
        new Dt("20051007T103000", true),
        new Dt("20051014T103000", true),
        new Dt("20051021T103000", true),
        new Dt("20051017T183000", true),
        new Dt("20051017T093000", true),
        new Dt("20051028T103000", true),
        new Dt("20051104T103000", false),
        new Dt("20051202T103000", false),
        new Dt("20051111T103000", false),
        new Dt("20050920T160000", true),
        new Dt("20050914T183000", true),
        new Dt("20050928T093000", true),
        new Dt("20050909T120000", true),
        new Dt("20050914T130000", true),
        new Dt("20050921T160000", true),
        new Dt("20050928T160000", true),
        new Dt("20051005T160000", true),
        new Dt("20051012T160000", true),
        new Dt("20051019T160000", true),
        new Dt("20051026T160000", true),
        new Dt("20051102T160000", false),
        new Dt("20051116T160000", false),
        new Dt("20050922T160000", true),
        new Dt("20050913T160000", true),
        new Dt("20050915T190000", true),
        new Dt("20050928T160000", true),
        new Dt("20050929T160000", true),
        new Dt("20051003T120000", true),
        new Dt("20050912T170000", true),
        new Dt("20050913T130000", true),
        new Dt("20050916T140000", true),
        new Dt("20050919T170000", true),
        new Dt("20051011T170000", true),
        new Dt("20050914T160000", true),
        new Dt("20050926T160000", true),
        new Dt("20051003T140000", true),
        new Dt("20051017T160000", true),
        new Dt("20051001T140000", true),
        new Dt("20051107T160000", false),
        new Dt("20051114T160000", false),
        new Dt("20051121T160000", false),
        new Dt("20051205T160000", false),
        new Dt("20051004T160000", true),
        new Dt("20050914T173000", true),
        new Dt("20050921T173000", true),
        new Dt("20050928T173000", true),
        new Dt("20051005T173000", true),
        new Dt("20051012T173000", true),
        new Dt("20051019T173000", true),
        new Dt("20051026T173000", true),
        new Dt("20051102T173000", false),
        new Dt("20050919T090000", true),
        new Dt("20050927T170000", true),
        new Dt("20051029T140000", true),
        new Dt("20050914T100000", true),
        new Dt("20050914T183000", true),
        new Dt("20051113T130000", false),
        new Dt("20060118T160000", false),
        new Dt("20060114T120000", false),
        new Dt("20060121T120000", false),
        new Dt("20060329T150000", true),
        new Dt("20060401T130000", true),
        new Dt("20060408T140000", true),
        new Dt("20060418T160000", true),
        new Dt("20050923T190000", true),
        new Dt("20060325T130000", true),
        new Dt("20060326T120000", true),
        new Dt("20060329T153000", true),
        new Dt("20050924T190000", true),
        new Dt("20050930T170000", true),
        new Dt("20051013T100000", true),
        new Dt("20051019T193000", true),
        new Dt("20051027T190000", true),
        new Dt("20051116T193000", false),
        new Dt("20050928T090000", true),
        new Dt("20060401T130000", true),
        new Dt("20060404T160000", true),
        new Dt("20060412T160000", true),
        new Dt("20060415T130000", true),
        new Dt("20060416T120000", true),
        new Dt("20060422T120000", true),
        new Dt("20060429T120000", true),
        new Dt("20060502T163000", true),
        new Dt("20060506T130000", true),
        new Dt("20060415T130000", true),
        new Dt("20060418T153000", true),
        new Dt("20060428T150000", true),
        new Dt("20060430T130000", true),
        new Dt("20050916T100000", true),
        new Dt("20050918T173000", true),
        new Dt("20050919T100000", true),
        new Dt("20050929T183000", true),
        new Dt("20051026T183000", true),
        new Dt("20050921T183000", true),
        new Dt("20050928T183000", true),
        new Dt("20050928T153000", true),
        new Dt("20050920T163000", true),
        new Dt("20051102T183000", false),
        new Dt("20050916T120000", true),
        new Dt("20050921T120000", true),
        new Dt("20051028T173000", true),
        new Dt("20051116T183000", false),
        new Dt("20050920T100000", true),
        new Dt("20050921T160000", true),
        new Dt("20050922T140000", true),
        new Dt("20050927T160000", true),
        new Dt("20050929T160000", true),
        new Dt("20050920T153000", true),
        new Dt("20050921T180000", true),
        new Dt("20050920T151500", true),
        new Dt("20050922T170000", true),
        new Dt("20050923T110000", true),
        new Dt("20050926T120000", true),
        new Dt("20050928T170000", true),
        new Dt("20050921T120000", true),
        new Dt("20050922T110000", true),
        new Dt("20050928T063000", true),
        new Dt("20050929T161500", true),
        new Dt("20050927T190000", true),
        new Dt("20051003T170000", true),
        new Dt("20050928T160000", true),
        new Dt("20051027T150000", true),
        new Dt("20050929T190000", true),
        new Dt("20051006T160000", true),
        new Dt("20050928T123000", true),
        new Dt("20051001T200000", true),
        new Dt("20051017T193000", true),
        new Dt("20051021T120000", true),
        new Dt("20051023T190000", true),
        new Dt("20051105T200000", false),
        new Dt("20051106T160000", false),
        new Dt("20051209T200000", false),
        new Dt("20060204T200000", false),
        new Dt("20060217T200000", false),
        new Dt("20060218T200000", false),
        new Dt("20060219T160000", false),
        new Dt("20060309T200000", true),
        new Dt("20060318T200000", true),
        new Dt("20060311T200000", true),
        new Dt("20060321T200000", true),
        new Dt("20060326T160000", true),
        new Dt("20060406T200000", true),
        new Dt("20060407T200000", true),
        new Dt("20060409T160000", true),
        new Dt("20060421T200000", true),
        new Dt("20060423T200000", true),
        new Dt("20060505T200000", true),
        new Dt("20051006T193000", true),
        new Dt("20051103T193000", false),
        new Dt("20060206T193000", false),
        new Dt("20060330T193000", true),
        new Dt("20050928T183000", true),
        new Dt("20050929T183000", true),
        new Dt("20050929T183000", true),
        new Dt("20050930T163000", true),
        new Dt("20050930T170000", true),
        new Dt("20050930T110000", true),
        new Dt("20050930T140000", true),
        new Dt("20051021T200000", true),
        new Dt("20051119T190000", false),
        new Dt("20060119T193000", false),
        new Dt("20051025T190000", true),
        new Dt("20060307T190000", true),
        new Dt("20050929T180000", true),
        new Dt("20050930T190000", true),
        new Dt("20050930T140000", true),
        new Dt("20050930T170000", true),
        new Dt("20051001T140000", true),
        new Dt("20051020T183000", true),
        new Dt("20051003T170000", true),
        new Dt("20051005T120000", true),
        new Dt("20051007T150000", true),
        new Dt("20051006T190000", true),
        new Dt("20051005T170000", true),
        new Dt("20051012T150000", true),
        new Dt("20051027T180000", true),
        new Dt("20051029T150000", true),
        new Dt("20051116T180000", false),
        new Dt("20051109T180000", false),
        new Dt("20051006T160000", true),
        new Dt("20051004T160000", true),
        new Dt("20051025T160000", true),
        new Dt("20051115T160000", false),
        new Dt("20051007T100000", true),
        new Dt("20051005T183000", true),
        new Dt("20051019T163000", true),
        new Dt("20051006T183000", true),
        new Dt("20051012T183000", true),
        new Dt("20051005T183000", true),
        new Dt("20051019T183000", true),
        new Dt("20051026T183000", true),
        new Dt("20051102T183000", false),
        new Dt("20051109T183000", false),
        new Dt("20051116T183000", false),
        new Dt("20051112T130000", false),
        new Dt("20051123T183000", false),
        new Dt("20051130T183000", false),
        new Dt("20051107T183000", false),
        new Dt("20051011T183000", true),
        new Dt("20051006T183000", true),
        new Dt("20051011T190000", true),
        new Dt("20051012T170000", true),
        new Dt("20051017T100000", true),
        new Dt("20051022T100000", true),
        new Dt("20051109T180000", false),
        new Dt("20051011T160000", true),
        new Dt("20051020T160000", true),
        new Dt("20051011T180000", true),
        new Dt("20051027T160000", true),
        new Dt("20051015T130000", true),
        new Dt("20051012T180000", true),
        new Dt("20051013T180000", true),
        new Dt("20051014T180000", true),
        new Dt("20051110T160000", false),
        new Dt("20051027T160000", true),
        new Dt("20051208T160000", false),
        new Dt("20051109T160000", false),
        new Dt("20051012T183000", true),
        new Dt("20051017T183000", true),
        new Dt("20051018T190000", true),
        new Dt("20051014T150000", true),
        new Dt("20051012T183000", true),
        new Dt("20051017T090000", true),
        new Dt("20051013T183000", true),
        new Dt("20051013T190000", true),
        new Dt("20051013T183000", true),
        new Dt("20051016T180000", true),
        new Dt("20051017T190000", true),
        new Dt("20051017T123000", true),
        new Dt("20051019T190000", true),
        new Dt("20051025T183000", true),
        new Dt("20051011T160000", true),
        new Dt("20051019T160000", true),
        new Dt("20051018T160000", true),
        new Dt("20051029T190000", true),
        new Dt("20051108T160000", false),
        new Dt("20051102T160000", false),
        new Dt("20051108T090000", false),
        new Dt("20051109T090000", false),
        new Dt("20051110T090000", false),
        new Dt("20051111T090000", false),
        new Dt("20051115T090000", false),
        new Dt("20051116T110000", false),
        new Dt("20051117T090000", false),
        new Dt("20051118T090000", false),
        new Dt("20051129T090000", false),
        new Dt("20051130T110000", false),
        new Dt("20051206T090000", false),
        new Dt("20051207T110000", false),
        new Dt("20051208T090000", false),
        new Dt("20051209T090000", false),
        new Dt("20051213T090000", false),
        new Dt("20051214T110000", false),
        new Dt("20051215T090000", false),
        new Dt("20051216T090000", false),
        new Dt("20051018T200000", true),
        new Dt("20051019T120000", true),
        new Dt("20051014T120000", true),
        new Dt("20051014T140000", true),
        new Dt("20051014T173000", true),
        new Dt("20051025T090000", true),
        new Dt("20051114T090000", false),
        new Dt("20051212T090000", false),
        new Dt("20051026T160000", true),
        new Dt("20051025T170000", true),
        new Dt("20051114T120000", false),
        new Dt("20051026T180000", true),
        new Dt("20051027T100000", true),
        new Dt("20051026T170000", true),
        new Dt("20051116T120000", false),
        new Dt("20051017T160000", true),
        new Dt("20051019T130000", true),
        new Dt("20051024T160000", true),
        new Dt("20051102T113000", false),
        new Dt("20051019T093000", true),
        new Dt("20051103T160000", false),
        new Dt("20051020T190000", true),
        new Dt("20051019T180000", true),
        new Dt("20051101T120000", false),
        new Dt("20051025T150000", true),
        new Dt("20051025T140000", true),
        new Dt("20051026T190000", true),
        new Dt("20051026T180000", true),
        new Dt("20051027T190000", true),
        new Dt("20051102T040000", false),
        new Dt("20051026T180000", true),
        new Dt("20051026T070000", true),
        new Dt("20051025T153000", true),
        new Dt("20051109T120000", false),
        new Dt("20051026T120000", true),
        new Dt("20060221T083000", false),
        new Dt("20060305T190000", true),
        new Dt("20060402T093000", true),
        new Dt("20051027T123000", true),
        new Dt("20051101T153000", false),
        new Dt("20051118T110000", false),
        new Dt("20051102T140000", false),
        new Dt("20051103T160000", false),
        new Dt("20051110T160000", false),
        new Dt("20051117T160000", false),
        new Dt("20051201T160000", false),
        new Dt("20051208T160000", false),
        new Dt("20051102T100000", false),
        new Dt("20051109T100000", false),
        new Dt("20051116T100000", false),
        new Dt("20051108T180000", false),
        new Dt("20051031T160000", true),
        new Dt("20051114T183000", false),
        new Dt("20051121T183000", false),
        new Dt("20051128T183000", false),
        new Dt("20060130T180000", false),
        new Dt("20051102T130000", false),
        new Dt("20051103T121500", false),
        new Dt("20051102T183000", false),
        new Dt("20051107T183000", false),
        new Dt("20051108T190000", false),
        new Dt("20051103T103000", false),
        new Dt("20051116T150000", false),
        new Dt("20051115T160000", false),
        new Dt("20051111T120000", false),
        new Dt("20060420T193000", true),
        new Dt("20051209T163000", false),
        new Dt("20051103T193000", false),
        new Dt("20051107T153000", false),
        new Dt("20051108T100000", false),
        new Dt("20051108T153000", false),
        new Dt("20051108T183000", false),
        new Dt("20051107T190000", false),
        new Dt("20051114T093000", false),
        new Dt("20051117T190000", false),
        new Dt("20051117T190000", false),
        new Dt("20051109T100000", false),
        new Dt("20051109T160000", false),
        new Dt("20051114T120000", false),
        new Dt("20051111T160000", false),
        new Dt("20051115T153000", false),
        new Dt("20051114T110000", false),
        new Dt("20051207T183000", false),
        new Dt("20051214T073000", false),
        new Dt("20060215T110000", false),
        new Dt("20051121T130000", false),
        new Dt("20051117T190000", false),
        new Dt("20051117T190000", false),
        new Dt("20051121T153000", false),
        new Dt("20051117T060000", false),
        new Dt("20051116T121500", false),
        new Dt("20051201T150000", false),
        new Dt("20051211T160000", false),
        new Dt("20051125T100000", false),
        new Dt("20051202T100000", false),
        new Dt("20051201T140000", false),
        new Dt("20051203T130000", false),
        new Dt("20051210T190000", false),
        new Dt("20051125T080000", false),
        new Dt("20051123T100000", false),
        new Dt("20051201T090000", false),
        new Dt("20051201T160000", false),
        new Dt("20051130T100000", false),
        new Dt("20051201T110000", false),
        new Dt("20051212T120000", false),
        new Dt("20051207T183000", false),
        new Dt("20051208T130000", false),
        new Dt("20051208T183000", false),
        new Dt("20051201T113000", false),
        new Dt("20051202T113000", false),
        new Dt("20051129T153000", false),
        new Dt("20051209T120000", false),
        new Dt("20051201T090000", false),
        new Dt("20051206T153000", false),
        new Dt("20051202T160000", false),
        new Dt("20051205T160000", false),
        new Dt("20051130T120000", false),
        new Dt("20051212T120000", false),
        new Dt("20051205T153000", false),
        new Dt("20051207T050000", false),
        new Dt("20051202T200000", false),
        new Dt("20051203T200000", false),
        new Dt("20060201T180000", false),
        new Dt("20060208T180000", false),
        new Dt("20060222T180000", false),
        new Dt("20060301T180000", true),
        new Dt("20060308T180000", true),
        new Dt("20060322T180000", true),
        new Dt("20060412T180000", true),
        new Dt("20051207T110000", false),
        new Dt("20051208T154500", false),
        new Dt("20060419T180000", true),
        new Dt("20060124T190000", false),
        new Dt("20060125T140000", false),
        new Dt("20060127T103000", false),
        new Dt("20060201T120000", false),
        new Dt("20060201T160000", false),
        new Dt("20060125T160000", false),
        new Dt("20060123T180000", false),
        new Dt("20060131T120000", false),
        new Dt("20060303T190000", true),
        new Dt("20060126T160000", false),
        new Dt("20060125T140000", false),
        new Dt("20060211T050000", false),
        new Dt("20060124T210000", false),
        new Dt("20060123T110000", false),
        new Dt("20060120T163000", false),
        new Dt("20060119T090000", false),
        new Dt("20060202T160000", false),
        new Dt("20060120T100000", false),
        new Dt("20060323T193000", true),
        new Dt("20060125T190000", false),
        new Dt("20060126T190000", false),
        new Dt("20060201T190000", false),
        new Dt("20060208T190000", false),
        new Dt("20060209T190000", false),
        new Dt("20060202T190000", false),
        new Dt("20060215T193000", false),
        new Dt("20060301T193000", true),
        new Dt("20060322T190000", true),
        new Dt("20060330T193000", true),
        new Dt("20060419T193000", true),
        new Dt("20060426T080000", true),
        new Dt("20060422T080000", true),
        new Dt("20051220T150000", false),
        new Dt("20060116T180000", false),
        new Dt("20060117T180000", false),
        new Dt("20060118T190000", false),
        new Dt("20060211T090000", false),
        new Dt("20060120T200000", false),
        new Dt("20060121T170000", false),
        new Dt("20060128T200000", false),
        new Dt("20060128T180000", false),
        new Dt("20060203T200000", false),
        new Dt("20060203T200000", false),
        new Dt("20060204T190000", false),
        new Dt("20060204T200000", false),
        new Dt("20060209T190000", false),
        new Dt("20060211T110000", false),
        new Dt("20060224T190000", false),
        new Dt("20060225T190000", false),
        new Dt("20060225T200000", false),
        new Dt("20060303T180000", true),
        new Dt("20060304T200000", true),
        new Dt("20060304T190000", true),
        new Dt("20060324T220000", true),
        new Dt("20060324T200000", true),
        new Dt("20060325T193000", true),
        new Dt("20060325T200000", true),
        new Dt("20060331T190000", true),
        new Dt("20060331T200000", true),
        new Dt("20060401T200000", true),
        new Dt("20060401T200000", true),
        new Dt("20060407T180000", true),
        new Dt("20060408T090000", true),
        new Dt("20060408T190000", true),
        new Dt("20060421T200000", true),
        new Dt("20060414T200000", true),
        new Dt("20060422T200000", true),
        new Dt("20060428T200000", true),
        new Dt("20060429T180000", true),
        new Dt("20060429T200000", true),
        new Dt("20060512T143500", true),
        new Dt("20060505T200000", true),
        new Dt("20060106T090000", false),
        new Dt("20060112T090000", false),
        new Dt("20060113T090000", false),
        new Dt("20060117T090000", false),
        new Dt("20060118T113000", false),
        new Dt("20060119T090000", false),
        new Dt("20060120T090000", false),
        new Dt("20060124T090000", false),
        new Dt("20060125T113000", false),
        new Dt("20060126T090000", false),
        new Dt("20060127T090000", false),
        new Dt("20060131T090000", false),
        new Dt("20060202T090000", false),
        new Dt("20060203T090000", false),
        new Dt("20060214T090000", false),
        new Dt("20060215T113000", false),
        new Dt("20060216T090000", false),
        new Dt("20060221T090000", false),
        new Dt("20060222T113000", false),
        new Dt("20060223T090000", false),
        new Dt("20060224T090000", false),
        new Dt("20060228T090000", false),
        new Dt("20060307T090000", true),
        new Dt("20060309T090000", true),
        new Dt("20060310T090000", true),
        new Dt("20060314T090000", true),
        new Dt("20060315T113000", true),
        new Dt("20060316T090000", true),
        new Dt("20060316T140000", true),
        new Dt("20060322T090000", true),
        new Dt("20060328T090000", true),
        new Dt("20060329T113000", true),
        new Dt("20060404T090000", true),
        new Dt("20060406T090000", true),
        new Dt("20060407T090000", true),
        new Dt("20060411T090000", true),
        new Dt("20060412T113000", true),
        new Dt("20060413T090000", true),
        new Dt("20060414T090000", true),
        new Dt("20060419T113000", true),
        new Dt("20060421T090000", true),
        new Dt("20060426T090000", true),
        new Dt("20070209T110000", false),
        new Dt("20051230T113000", false),
        new Dt("20060207T163000", false),
        new Dt("20060114T080000", false),
        new Dt("20060320T100000", true),
        new Dt("20060105T140000", false),
        new Dt("20060118T160000", false),
        new Dt("20060208T160000", false),
        new Dt("20060125T160000", false),
        new Dt("20060215T160000", false),
        new Dt("20060301T160000", true),
        new Dt("20060223T180000", false),
        new Dt("20060418T090000", true),
        new Dt("20060412T160000", true),
        new Dt("20060113T120000", false),
        new Dt("20060130T173000", false),
        new Dt("20060211T163000", false),
        new Dt("20060211T113000", false),
        new Dt("20060218T110000", false),
        new Dt("20060211T120000", false),
        new Dt("20060216T120000", false),
        new Dt("20060106T160000", false),
        new Dt("20060119T100000", false),
        new Dt("20060118T093000", false),
        new Dt("20060124T160000", false),
        new Dt("20060207T160000", false),
        new Dt("20060117T090000", false),
        new Dt("20060214T090000", false),
        new Dt("20060314T090000", true),
        new Dt("20060120T103000", false),
        new Dt("20060208T093000", false),
        new Dt("20060323T183000", true),
        new Dt("20060320T160000", true),
        new Dt("20060125T093000", false),
        new Dt("20060301T093000", true),
        new Dt("20060329T093000", true),
        new Dt("20060419T093000", true),
        new Dt("20060503T093000", true),
        new Dt("20060118T130000", false),
        new Dt("20060119T150000", false),
        new Dt("20060120T120000", false),
        new Dt("20060120T130000", false),
        new Dt("20060120T153000", false),
        new Dt("20060127T170000", false),
        new Dt("20060124T190000", false),
        new Dt("20060131T153000", false),
        new Dt("20060207T153000", false),
        new Dt("20060214T153000", false),
        new Dt("20060130T160000", false),
        new Dt("20060206T160000", false),
        new Dt("20060227T160000", false),
        new Dt("20060403T161000", true),
        new Dt("20060404T160000", true),
        new Dt("20060410T160000", true),
        new Dt("20060417T160000", true),
        new Dt("20060424T160000", true),
        new Dt("20060329T180000", true),
        new Dt("20060130T180000", false),
        new Dt("20060206T160000", false),
        new Dt("20060208T123000", false),
        new Dt("20060213T160000", false),
        new Dt("20060221T160000", false),
        new Dt("20060227T160000", false),
        new Dt("20060301T120000", true),
        new Dt("20060322T123000", true),
        new Dt("20060329T153000", true),
        new Dt("20060306T160000", true),
        new Dt("20060320T160000", true),
        new Dt("20060327T160000", true),
        new Dt("20060125T123000", false),
        new Dt("20060403T160000", true),
        new Dt("20060410T160000", true),
        new Dt("20060417T160000", true),
        new Dt("20060424T160000", true),
        new Dt("20060130T160000", false),
        new Dt("20060509T000000", true),
        new Dt("20060306T193000", true),
        new Dt("20060128T200000", false),
        new Dt("20060127T140000", false),
        new Dt("20060203T103000", false),
        new Dt("20060125T173000", false),
        new Dt("20060201T173000", false),
        new Dt("20060208T173000", false),
        new Dt("20060215T173000", false),
        new Dt("20060222T173000", false),
        new Dt("20060301T173000", true),
        new Dt("20060308T173000", true),
        new Dt("20060315T173000", true),
        new Dt("20060322T173000", true),
        new Dt("20060329T173000", true),
        new Dt("20060405T173000", true),
        new Dt("20060412T173000", true),
        new Dt("20060419T173000", true),
        new Dt("20060131T110000", false),
        new Dt("20060202T160000", false),
        new Dt("20060216T160000", false),
        new Dt("20060209T160000", false),
        new Dt("20060223T160000", false),
        new Dt("20060207T090000", false),
        new Dt("20060206T100000", false),
        new Dt("20060210T103000", false),
        new Dt("20060210T120000", false),
        new Dt("20060201T060000", false),
        new Dt("20060215T140000", false),
        new Dt("20061013T160000", true),
        new Dt("20060906T093000", true),
        new Dt("20061220T120000", false),
        new Dt("20070512T120000", true),
        new Dt("20060306T160000", true),
        new Dt("20060211T050000", false),
        new Dt("20060314T090000", true),
        new Dt("20060517T090000", true),
        new Dt("20060411T090000", true),
        new Dt("20060204T200000", false),
        new Dt("20060211T200000", false),
        new Dt("20060218T200000", false),
        new Dt("20060228T153000", false),
        new Dt("20060216T160000", false),
        new Dt("20060208T150000", false),
        new Dt("20060214T160000", false),
        new Dt("20060302T170000", true),
        new Dt("20060307T160000", true),
        new Dt("20060309T120000", true),
        new Dt("20060412T120000", true),
        new Dt("20060208T120000", false),
        new Dt("20060210T130000", false),
        new Dt("20060223T150000", false),
        new Dt("20060207T150000", false),
        new Dt("20060209T140000", false),
        new Dt("20060213T160000", false),
        new Dt("20060215T150000", false),
        new Dt("20060206T180000", false),
        new Dt("20060420T120000", true),
        new Dt("20060202T090000", false),
        new Dt("20060224T153000", false),
        new Dt("20060206T180000", false),
        new Dt("20060220T180000", false),
        new Dt("20060213T180000", false),
        new Dt("20060227T180000", false),
        new Dt("20060306T180000", true),
        new Dt("20060320T180000", true),
        new Dt("20060313T180000", true),
        new Dt("20060327T180000", true),
        new Dt("20060403T180000", true),
        new Dt("20060217T192500", false),
        new Dt("20060410T180000", true),
        new Dt("20060417T180000", true),
        new Dt("20060424T180000", true),
        new Dt("20060501T180000", true),
        new Dt("20060208T160000", false),
        new Dt("20060215T160000", false),
        new Dt("20060222T160000", false),
        new Dt("20060301T160000", true),
        new Dt("20060308T160000", true),
        new Dt("20060315T160000", true),
        new Dt("20060322T160000", true),
        new Dt("20060329T160000", true),
        new Dt("20060405T160000", true),
        new Dt("20060412T160000", true),
        new Dt("20060419T160000", true),
        new Dt("20060426T160000", true),
        new Dt("20060503T160000", true),
        new Dt("20060309T180000", true),
        new Dt("20060217T140000", false),
        new Dt("20060224T140000", false),
        new Dt("20060303T140000", true),
        new Dt("20060228T190000", false),
        new Dt("20060224T133000", false),
        new Dt("20060215T170000", false),
        new Dt("20060221T170000", false),
        new Dt("20060221T120000", false),
        new Dt("20060215T180000", false),
        new Dt("20060216T180000", false),
        new Dt("20060301T173000", true),
        new Dt("20060215T140000", false),
        new Dt("20060227T110000", false),
        new Dt("20060228T120000", false),
        new Dt("20060215T110000", false),
        new Dt("20060225T090000", false),
        new Dt("20060417T080000", true),
        new Dt("20060224T103000", false),
        new Dt("20060303T200000", true),
        new Dt("20060331T180000", true),
        new Dt("20060225T200000", false),
        new Dt("20060419T200000", true),
        new Dt("20060222T210000", false),
        new Dt("20060307T150000", true),
        new Dt("20060307T153000", true),
        new Dt("20060303T103000", true),
        new Dt("20060302T153000", true),
        new Dt("20060310T180000", true),
        new Dt("20060302T160000", true),
        new Dt("20060331T180000", true),
        new Dt("20060303T190000", true),
        new Dt("20060304T190000", true),
        new Dt("20060308T190000", true),
        new Dt("20060304T200000", true),
        new Dt("20060301T023000", true),
        new Dt("20060304T140000", true),
        new Dt("20060307T160000", true),
        new Dt("20060301T183000", true),
        new Dt("20060301T183000", true),
        new Dt("20060302T190000", true),
        new Dt("20060309T093000", true),
        new Dt("20060307T190000", true),
        new Dt("20060302T183000", true),
        new Dt("20060313T103000", true),
        new Dt("20060306T074500", true),
        new Dt("20060307T130000", true),
        new Dt("20060306T160000", true),
        new Dt("20060309T160500", true),
        new Dt("20060423T160000", true),
        new Dt("20060306T163000", true),
        new Dt("20060308T190000", true),
        new Dt("20060329T160000", true),
        new Dt("20060310T103000", true),
        new Dt("20060314T063000", true),
        new Dt("20060320T153000", true),
        new Dt("20060331T120000", true),
        new Dt("20060308T163000", true),
        new Dt("20060414T160000", true),
        new Dt("20060324T143000", true),
        new Dt("20060308T140000", true),
        new Dt("20060405T120000", true),
        new Dt("20060317T103000", true),
        new Dt("20060317T160000", true),
        new Dt("20060323T160000", true),
        new Dt("20060406T160000", true),
        new Dt("20060330T160000", true),
        new Dt("20060413T160000", true),
        new Dt("20060420T160000", true),
        new Dt("20060321T153000", true),
        new Dt("20060323T160000", true),
        new Dt("20060330T160000", true),
        new Dt("20060329T160000", true),
        new Dt("20060516T090000", true),
        new Dt("20060620T090000", true),
        new Dt("20060316T050000", true),
        new Dt("20060324T103000", true),
        new Dt("20060329T143000", true),
        new Dt("20060419T143000", true),
        new Dt("20060419T160000", true),
        new Dt("20060428T170000", true),
        new Dt("20060429T100000", true),
        new Dt("20060323T160000", true),
        new Dt("20060330T160000", true),
        new Dt("20060321T190000", true),
        new Dt("20060323T173000", true),
        new Dt("20060405T203000", true),
        new Dt("20060406T180000", true),
        new Dt("20060413T170000", true),
        new Dt("20060429T190000", true),
        new Dt("20060502T173000", true),
        new Dt("20060403T140000", true),
        new Dt("20060406T154500", true),
        new Dt("20060331T140000", true),
        new Dt("20060425T120000", true),
        new Dt("20060327T160000", true),
        new Dt("20060322T110000", true),
        new Dt("20060412T110000", true),
        new Dt("20060327T160000", true),
        new Dt("20060328T120000", true),
        new Dt("20060330T150000", true),
        new Dt("20060412T120000", true),
        new Dt("20060419T120000", true),
        new Dt("20060328T153000", true),
        new Dt("20060331T103000", true),
        new Dt("20060405T180000", true),
        new Dt("20060510T180000", true),
        new Dt("20060607T180000", true),
        new Dt("20060712T180000", true),
        new Dt("20060504T180000", true),
        new Dt("20060406T180000", true),
        new Dt("20060329T160000", true),
        new Dt("20060417T150000", true),
        new Dt("20060403T140000", true),
        new Dt("20060412T150000", true),
        new Dt("20060405T103000", true),
        new Dt("20060407T103000", true),
        new Dt("20060404T153000", true),
        new Dt("20060331T140000", true),
        new Dt("20060406T160000", true),
        new Dt("20060420T160000", true),
        new Dt("20060501T160000", true),
        new Dt("20060505T160000", true),
        new Dt("20060925T080000", true),
        new Dt("20060404T163000", true),
        new Dt("20060405T170000", true),
        new Dt("20060403T150000", true),
        new Dt("20060404T110000", true),
        new Dt("20060405T170000", true),
        new Dt("20060405T110000", true),
        new Dt("20060412T110000", true),
        new Dt("20060522T090000", true),
        new Dt("20060517T130000", true),
        new Dt("20060529T090000", true),
        new Dt("20060605T090000", true),
        new Dt("20060614T130000", true),
        new Dt("20060414T103000", true),
        new Dt("20060413T153000", true),
        new Dt("20060411T153000", true),
        new Dt("20060418T170000", true),
        new Dt("20060406T190000", true),
        new Dt("20060410T170000", true),
        new Dt("20060412T173000", true),
        new Dt("20060408T110000", true),
        new Dt("20060404T160000", true),
        new Dt("20060406T160000", true),
        new Dt("20060412T160000", true),
        new Dt("20060420T160000", true),
        new Dt("20060427T160000", true),
        new Dt("20060510T160000", true),
        new Dt("20060410T100000", true),
        new Dt("20061015T000000", true),
        new Dt("20060603T000000", true),
        new Dt("20061017T000000", true),
        new Dt("20060622T000000", true),
        new Dt("20060726T000000", true),
        new Dt("20061106T000000", false),
        new Dt("20060417T000000", true),
        new Dt("20061109T000000", false),
        new Dt("20060607T000000", true),
        new Dt("20060711T000000", true),
        new Dt("20060906T000000", true),
        new Dt("20060407T120000", true),
        new Dt("20060419T023000", true),
        new Dt("20060421T190000", true),
        new Dt("20060411T090000", true),
        new Dt("20060512T120000", true),
        new Dt("20060417T160000", true),
        new Dt("20060411T153000", true),
        new Dt("20060413T153000", true),
        new Dt("20060411T130000", true),
        new Dt("20060419T160000", true),
        new Dt("20060421T110000", true),
        new Dt("20060506T200000", true),
        new Dt("20060421T103000", true),
        new Dt("20060427T153000", true),
        new Dt("20060425T160000", true),
        new Dt("20060419T180000", true),
        new Dt("20060420T100000", true),
        new Dt("20060420T053000", true),
        new Dt("20060417T120000", true),
        new Dt("20060418T120000", true),
        new Dt("20060426T113000", true),
        new Dt("20060428T103000", true),
        new Dt("20060427T170000", true),
        new Dt("20060418T164000", true),
        new Dt("20060426T140000", true),
        new Dt("20060501T040000", true),
        new Dt("20060421T170000", true),
        new Dt("20060421T200000", true),
        new Dt("20060422T200000", true),
        new Dt("20060427T200000", true),
        new Dt("20060428T200000", true),
        new Dt("20060429T200000", true),
        new Dt("20060425T080000", true),
        new Dt("20060428T190000", true),
        new Dt("20060429T190000", true),
        new Dt("20060430T130000", true),
        new Dt("20060504T090000", true),
        new Dt("20060502T090000", true),
        new Dt("20060505T090000", true),
        new Dt("20060509T090000", true),
        new Dt("20060510T090000", true),
        new Dt("20060523T090000", true),
        new Dt("20060525T090000", true),
        new Dt("20060525T100000", true),
        new Dt("20060526T090000", true),
        new Dt("20060524T090000", true),
        new Dt("20060531T090000", true),
        new Dt("20060606T090000", true),
        new Dt("20060613T090000", true),
        new Dt("20060614T090000", true),
        new Dt("20060615T090000", true),
        new Dt("20060616T090000", true),
        new Dt("20060620T090000", true),
        new Dt("20060621T090000", true),
        new Dt("20060622T090000", true),
        new Dt("20060623T090000", true),
        new Dt("20060628T090000", true),
        new Dt("20060629T090000", true),
        new Dt("20060707T090000", true),
        new Dt("20060711T090000", true),
        new Dt("20060712T090000", true),
        new Dt("20060713T090000", true),
        new Dt("20060714T090000", true),
        new Dt("20060725T090000", true),
        new Dt("20060726T090000", true),
        new Dt("20060727T090000", true),
        new Dt("20060728T090000", true),
        new Dt("20060809T090000", true),
        new Dt("20060810T090000", true),
        new Dt("20060815T090000", true),
        new Dt("20060817T090000", true),
        new Dt("20060908T090000", true),
        new Dt("20060824T090000", true),
        new Dt("20060825T090000", true),
        new Dt("20060829T090000", true),
        new Dt("20060831T090000", true),
        new Dt("20060509T130000", true),
        new Dt("20060630T090000", true),
        new Dt("20060705T130000", true),
        new Dt("20060425T183000", true),
        new Dt("20060811T090000", true),
        new Dt("20060523T173000", true),
        new Dt("20060507T110000", true),
        new Dt("20060510T183000", true),
        new Dt("20060503T140000", true),
        new Dt("20060425T100000", true),
        new Dt("20060507T160000", true),
        new Dt("20060427T110000", true),
        new Dt("20060427T150000", true),
        new Dt("20060503T160000", true),
        new Dt("20060429T090000", true),
        new Dt("20060504T110000", true),
        new Dt("20060501T120000", true),
        new Dt("20060501T160000", true),
        new Dt("20060507T160000", true),
        new Dt("20060804T180000", true),
        new Dt("20060521T073000", true),
        new Dt("20060506T110000", true),
        new Dt("20060519T160000", true),
        new Dt("20060510T140000", true),
        new Dt("20060607T120000", true),
        new Dt("20060524T120000", true),
        new Dt("20060612T083000", true),
        new Dt("20060513T190000", true),
        new Dt("20060517T080000", true),
        new Dt("20060517T140000", true),
        new Dt("20060526T073000", true),
        new Dt("20060616T150000", true),
        new Dt("20060613T160000", true),
        new Dt("20060906T173000", true),
        new Dt("20060913T173000", true),
        new Dt("20060920T173000", true),
        new Dt("20060927T173000", true),
        new Dt("20061004T173000", true),
        new Dt("20061011T173000", true),
        new Dt("20061018T173000", true),
        new Dt("20061025T173000", true),
        new Dt("20061101T173000", false),
        new Dt("20061108T173000", false),
        new Dt("20061115T173000", false),
        new Dt("20060531T200000", true),
        new Dt("20060616T133000", true),
        new Dt("20060605T100000", true),
        new Dt("20060614T120000", true),
        new Dt("20060609T060000", true),
        new Dt("20060622T190000", true),
        new Dt("20060726T190000", true),
        new Dt("20060621T120000", true),
        new Dt("20060616T190000", true),
        new Dt("20060614T063000", true),
        new Dt("20060612T200000", true),
        new Dt("20060619T150000", true),
        new Dt("20060622T090000", true),
        new Dt("20060616T160000", true),
        new Dt("20060713T173000", true),
        new Dt("20060919T173000", true),
        new Dt("20061019T173000", true),
        new Dt("20061004T180000", true),
        new Dt("20061206T180000", false),
        new Dt("20061101T180000", false),
        new Dt("20060619T170000", true),
        new Dt("20060616T100000", true),
        new Dt("20060628T100000", true),
        new Dt("20060629T100000", true),
        new Dt("20060815T100000", true),
        new Dt("20060816T100000", true),
        new Dt("20060909T090000", true),
        new Dt("20061021T090000", true),
        new Dt("20061021T090000", true),
        new Dt("20070330T083000", true),
        new Dt("20070414T090000", true),
        new Dt("20061110T083000", false),
        new Dt("20060712T063000", true),
        new Dt("20060621T120000", true),
        new Dt("20060712T063000", true),
        new Dt("20060623T140000", true),
        new Dt("20060630T090000", true),
        new Dt("20060626T140000", true),
        new Dt("20060628T063000", true),
        new Dt("20060629T140000", true),
        new Dt("20060628T120000", true),
        new Dt("20061026T000000", true),
        new Dt("20060707T190000", true),
        new Dt("20060707T200000", true),
        new Dt("20060718T113000", true),
        new Dt("20060728T180000", true),
        new Dt("20060728T190000", true),
        new Dt("20060803T113000", true),
        new Dt("20060728T200000", true),
        new Dt("20060802T200000", true),
        new Dt("20060805T140000", true),
        new Dt("20060804T200000", true),
        new Dt("20060805T200000", true),
        new Dt("20060810T200000", true),
        new Dt("20060813T140000", true),
        new Dt("20060804T193000", true),
        new Dt("20060809T193000", true),
        new Dt("20060809T180000", true),
        new Dt("20060712T180000", true),
        new Dt("20060718T160000", true),
        new Dt("20060711T190000", true),
        new Dt("20060710T160000", true),
        new Dt("20060705T120000", true),
        new Dt("20060706T110000", true),
        new Dt("20060913T160000", true),
        new Dt("20060712T120000", true),
        new Dt("20060822T110000", true),
        new Dt("20060822T163000", true),
        new Dt("20060714T070000", true),
        new Dt("20060726T053000", true),
        new Dt("20060726T053000", true),
        new Dt("20060920T110000", true),
        new Dt("20060719T120000", true),
        new Dt("20061020T000000", true),
        new Dt("20060825T120000", true),
        new Dt("20060809T090000", true),
        new Dt("20060726T120000", true),
        new Dt("20060727T193000", true),
        new Dt("20060728T103000", true),
        new Dt("20060731T140000", true),
        new Dt("20061117T110000", false),
        new Dt("20060912T160000", true),
        new Dt("20060916T083000", true),
        new Dt("20060808T090000", true),
        new Dt("20060809T120000", true),
        new Dt("20060914T200000", true),
        new Dt("20061012T123000", true),
        new Dt("20061116T190000", false),
        new Dt("20060919T090000", true),
        new Dt("20061012T090000", true),
        new Dt("20061106T090000", false),
        new Dt("20061010T090000", true),
        new Dt("20061212T090000", false),
        new Dt("20060816T120000", true),
        new Dt("20060822T133000", true),
        new Dt("20061127T160000", false),
        new Dt("20060920T160000", true),
        new Dt("20061025T183000", true),
        new Dt("20060921T230000", true),
        new Dt("20060825T173000", true),
        new Dt("20060905T110000", true),
        new Dt("20060906T103000", true),
        new Dt("20060913T090000", true),
        new Dt("20060914T090000", true),
        new Dt("20060915T090000", true),
        new Dt("20060919T090000", true),
        new Dt("20060919T130000", true),
        new Dt("20060920T120000", true),
        new Dt("20060921T090000", true),
        new Dt("20060921T100000", true),
        new Dt("20060922T090000", true),
        new Dt("20060926T090000", true),
        new Dt("20060927T120000", true),
        new Dt("20060928T090000", true),
        new Dt("20061003T083000", true),
        new Dt("20061005T090000", true),
        new Dt("20061018T090000", true),
        new Dt("20061019T100000", true),
        new Dt("20061020T090000", true),
        new Dt("20061103T090000", false),
        new Dt("20061107T090000", false),
        new Dt("20061108T090000", false),
        new Dt("20061109T090000", false),
        new Dt("20061110T083000", false),
        new Dt("20061114T090000", false),
        new Dt("20061115T120000", false),
        new Dt("20061116T090000", false),
        new Dt("20061128T090000", false),
        new Dt("20061129T090000", false),
        new Dt("20061130T090000", false),
        new Dt("20061205T090000", false),
        new Dt("20061207T083000", false),
        new Dt("20061212T090000", false),
        new Dt("20061213T120000", false),
        new Dt("20061215T090000", false),
        new Dt("20061219T090000", false),
        new Dt("20061221T090000", false),
        new Dt("20061222T090000", false),
        new Dt("20060823T130000", true),
        new Dt("20060823T150000", true),
        new Dt("20060927T160000", true),
        new Dt("20061004T160000", true),
        new Dt("20061018T160000", true),
        new Dt("20061108T160000", false),
        new Dt("20060929T100000", true),
        new Dt("20060930T100000", true),
        new Dt("20060907T100000", true),
        new Dt("20060830T110000", true),
        new Dt("20061108T093000", false),
        new Dt("20060920T093000", true),
        new Dt("20061014T140000", true),
        new Dt("20060927T113000", true),
        new Dt("20061025T093000", true),
        new Dt("20061129T093000", false),
        new Dt("20061011T093000", true),
        new Dt("20061012T093000", true),
        new Dt("20061115T160000", false),
        new Dt("20061101T160000", false),
        new Dt("20060913T180000", true),
        new Dt("20060914T160000", true),
        new Dt("20060914T180000", true),
        new Dt("20060918T120000", true),
        new Dt("20060918T160000", true),
        new Dt("20060919T130000", true),
        new Dt("20060920T150000", true),
        new Dt("20060921T110000", true),
        new Dt("20060922T120000", true),
        new Dt("20060906T130000", true),
        new Dt("20060906T180000", true),
        new Dt("20060906T180000", true),
        new Dt("20060911T180000", true),
        new Dt("20060918T180000", true),
        new Dt("20060925T180000", true),
        new Dt("20061002T180000", true),
        new Dt("20061016T180000", true),
        new Dt("20061023T180000", true),
        new Dt("20061030T180000", true),
        new Dt("20061106T180000", false),
        new Dt("20061113T180000", false),
        new Dt("20061206T180000", false),
        new Dt("20061120T180000", false),
        new Dt("20061127T180000", false),
        new Dt("20061115T180000", false),
        new Dt("20060920T180000", true),
        new Dt("20060927T180000", true),
        new Dt("20061004T180000", true),
        new Dt("20061011T180000", true),
        new Dt("20061025T180000", true),
        new Dt("20061101T180000", false),
        new Dt("20061108T180000", false),
        new Dt("20060913T180000", true),
        new Dt("20061018T180000", true),
        new Dt("20061129T180000", false),
        new Dt("20061204T180000", false),
        new Dt("20061009T180000", true),
        new Dt("20061122T180000", false),
        new Dt("20060908T120000", true),
        new Dt("20060911T113000", true),
        new Dt("20060913T120000", true),
        new Dt("20061004T120000", true),
        new Dt("20061115T120000", false),
        new Dt("20061206T120000", false),
        new Dt("20070207T120000", false),
        new Dt("20070307T120000", true),
        new Dt("20070411T120000", true),
        new Dt("20070509T120000", true),
        new Dt("20060921T173000", true),
        new Dt("20060915T153000", true),
        new Dt("20060914T170000", true),
        new Dt("20060915T120000", true),
        new Dt("20060914T130000", true),
        new Dt("20060927T130000", true),
        new Dt("20060914T130000", true),
        new Dt("20060929T130000", true),
        new Dt("20060921T130000", true),
        new Dt("20060928T130000", true),
        new Dt("20060922T130000", true),
        new Dt("20061017T183000", true),
        new Dt("20060927T170000", true),
        new Dt("20060913T103000", true),
        new Dt("20060913T160000", true),
        new Dt("20061005T130000", true),
        new Dt("20061013T120000", true),
        new Dt("20061015T150000", true),
        new Dt("20060911T110000", true),
        new Dt("20060918T140000", true),
        new Dt("20060913T130000", true),
        new Dt("20061002T160000", true),
        new Dt("20060921T120000", true),
        new Dt("20060925T170000", true),
        new Dt("20060926T140000", true),
        new Dt("20060919T170000", true),
        new Dt("20061024T170000", true),
        new Dt("20061023T130000", true),
        new Dt("20061108T160000", false),
        new Dt("20061018T170000", true),
        new Dt("20060921T170000", true),
        new Dt("20060926T140000", true),
        new Dt("20061003T140000", true),
        new Dt("20061003T170000", true),
        new Dt("20061011T173000", true),
        new Dt("20061019T170000", true),
        new Dt("20061023T173000", true),
        new Dt("20060920T170000", true),
        new Dt("20061025T180000", true),
        new Dt("20061107T160000", false),
        new Dt("20061011T160000", true),
        new Dt("20060908T060000", true),
        new Dt("20060909T200000", true),
        new Dt("20061013T200000", true),
        new Dt("20061104T200000", false),
        new Dt("20061201T200000", false),
        new Dt("20060913T160000", true),
        new Dt("20060920T140000", true),
        new Dt("20060927T140000", true),
        new Dt("20060915T130000", true),
        new Dt("20060914T110000", true),
        new Dt("20060914T200000", true),
        new Dt("20061027T203000", true),
        new Dt("20061101T020000", false),
        new Dt("20061101T193000", false),
        new Dt("20060914T193000", true),
        new Dt("20061006T190000", true),
        new Dt("20060915T190000", true),
        new Dt("20060916T190000", true),
        new Dt("20060923T190000", true),
        new Dt("20060922T190000", true),
        new Dt("20060929T190000", true),
        new Dt("20060930T190000", true),
        new Dt("20060922T200000", true),
        new Dt("20061013T190000", true),
        new Dt("20061014T190000", true),
        new Dt("20060916T200000", true),
        new Dt("20061013T200000", true),
        new Dt("20061103T200000", false),
        new Dt("20061111T200000", false),
        new Dt("20061117T200000", false),
        new Dt("20061201T200000", false),
        new Dt("20060914T200000", true),
        new Dt("20060916T220000", true),
        new Dt("20060920T103000", true),
        new Dt("20060919T163000", true),
        new Dt("20060926T163000", true),
        new Dt("20061003T170000", true),
        new Dt("20061017T170000", true),
        new Dt("20060918T120000", true),
        new Dt("20061011T110000", true),
        new Dt("20060920T120000", true),
        new Dt("20060922T113000", true),
        new Dt("20060922T184500", true),
        new Dt("20060930T090000", true),
        new Dt("20061019T193000", true),
        new Dt("20061027T120000", true),
        new Dt("20061115T120000", false),
        new Dt("20061212T120000", false),
        new Dt("20060212T120000", false),
        new Dt("20060326T120000", true),
        new Dt("20060417T120000", true),
        new Dt("20060921T100000", true),
        new Dt("20060920T100000", true),
        new Dt("20061004T103000", true),
        new Dt("20060928T160000", true),
        new Dt("20060929T110000", true),
        new Dt("20060923T130000", true),
        new Dt("20061014T130000", true),
        new Dt("20061020T160000", true),
        new Dt("20061021T140000", true),
        new Dt("20061006T180000", true),
        new Dt("20061007T160000", true),
        new Dt("20061014T153000", true),
        new Dt("20061024T160000", true),
        new Dt("20060929T160000", true),
        new Dt("20061011T153000", true),
        new Dt("20060923T130000", true),
        new Dt("20060930T130000", true),
        new Dt("20061028T130000", true),
        new Dt("20061111T130000", false),
        new Dt("20060923T160000", true),
        new Dt("20061006T150000", true),
        new Dt("20061007T130000", true),
        new Dt("20061025T183000", true),
        new Dt("20061029T110000", true),
        new Dt("20061022T130000", true),
        new Dt("20061029T120000", true),
        new Dt("20061120T200000", false),
        new Dt("20061121T153000", false),
        new Dt("20061129T200000", false),
        new Dt("20061203T130000", false),
        new Dt("20061204T200000", false),
        new Dt("20061207T200000", false),
        new Dt("20061121T200000", false),
        new Dt("20061202T150000", false),
        new Dt("20061205T200000", false),
        new Dt("20061209T150000", false),
        new Dt("20060103T190000", false),
        new Dt("20060107T160000", false),
        new Dt("20060112T200000", false),
        new Dt("20060113T160000", false),
        new Dt("20060126T200000", false),
        new Dt("20060127T160000", false),
        new Dt("20060202T200000", false),
        new Dt("20060203T160000", false),
        new Dt("20060213T200000", false),
        new Dt("20061121T180000", false),
        new Dt("20061205T180000", false),
        new Dt("20061209T130000", false),
        new Dt("20060112T180000", false),
        new Dt("20060113T140000", false),
        new Dt("20060126T180000", false),
        new Dt("20060127T140000", false),
        new Dt("20060202T180000", false),
        new Dt("20070112T180000", false),
        new Dt("20070113T140000", false),
        new Dt("20070126T180000", false),
        new Dt("20070127T140000", false),
        new Dt("20070202T180000", false),
        new Dt("20070203T140000", false),
        new Dt("20070213T180000", false),
        new Dt("20070103T190000", false),
        new Dt("20070107T160000", false),
        new Dt("20070112T200000", false),
        new Dt("20070113T160000", false),
        new Dt("20070126T200000", false),
        new Dt("20070127T160000", false),
        new Dt("20070202T200000", false),
        new Dt("20070203T160000", false),
        new Dt("20070213T200000", false),
        new Dt("20061007T190000", true),
        new Dt("20061014T190000", true),
        new Dt("20061028T190000", true),
        new Dt("20061029T140000", true),
        new Dt("20061103T190000", false),
        new Dt("20061104T190000", false),
        new Dt("20061112T140000", false),
        new Dt("20061117T190000", false),
        new Dt("20060927T103000", true),
        new Dt("20061124T153000", false),
        new Dt("20061125T153000", false),
        new Dt("20061216T190000", false),
        new Dt("20070105T190000", false),
        new Dt("20070106T190000", false),
        new Dt("20070112T190000", false),
        new Dt("20070119T190000", false),
        new Dt("20070120T190000", false),
        new Dt("20070209T190000", false),
        new Dt("20070210T190000", false),
        new Dt("20070223T190000", false),
        new Dt("20070224T190000", false),
        new Dt("20060929T190000", true),
        new Dt("20061020T190000", true),
        new Dt("20061021T150000", true),
        new Dt("20061104T140000", false),
        new Dt("20061105T140000", false),
        new Dt("20061201T190000", false),
        new Dt("20061202T160000", false),
        new Dt("20061208T190000", false),
        new Dt("20070106T140000", false),
        new Dt("20070107T140000", false),
        new Dt("20070113T140000", false),
        new Dt("20070114T140000", false),
        new Dt("20070202T190000", false),
        new Dt("20070203T160000", false),
        new Dt("20070216T190000", false),
        new Dt("20070217T120000", false),
        new Dt("20070217T160000", false),
        new Dt("20061030T190000", true),
        new Dt("20060927T080000", true),
        new Dt("20061021T130000", true),
        new Dt("20061105T120000", false),
        new Dt("20060113T120000", false),
        new Dt("20070113T120000", false),
        new Dt("20070120T120000", false),
        new Dt("20070127T130000", false),
        new Dt("20070328T153000", true),
        new Dt("20070330T130000", true),
        new Dt("20070331T120000", true),
        new Dt("20070404T153000", true),
        new Dt("20070405T160000", true),
        new Dt("20070418T160000", true),
        new Dt("20070422T120000", true),
        new Dt("20070429T120000", true),
        new Dt("20070506T120000", true),
        new Dt("20070203T130000", false),
        new Dt("20070313T160000", true),
        new Dt("20070315T160000", true),
        new Dt("20070426T160000", true),
        new Dt("20070410T190000", true),
        new Dt("20070413T160000", true),
        new Dt("20070325T120000", true),
        new Dt("20070414T140000", true),
        new Dt("20070411T160000", true),
        new Dt("20070414T140000", true),
        new Dt("20070426T160000", true),
        new Dt("20070330T140000", true),
        new Dt("20070331T130000", true),
        new Dt("20070404T150000", true),
        new Dt("20070412T153000", true),
        new Dt("20070422T130000", true),
        new Dt("20070423T140000", true),
        new Dt("20070430T150000", true),
        new Dt("20061031T153000", true),
        new Dt("20060928T160000", true),
        new Dt("20061026T140000", true),
        new Dt("20060929T073000", true),
        new Dt("20061004T160000", true),
        new Dt("20061011T160000", true),
        new Dt("20061004T120000", true),
        new Dt("20061019T170000", true),
        new Dt("20061004T160000", true),
        new Dt("20061010T080000", true),
        new Dt("20061024T160000", true),
        new Dt("20061012T160000", true),
        new Dt("20061114T153000", false),
        new Dt("20061013T120000", true),
        new Dt("20061017T100000", true),
        new Dt("20061027T093000", true),
        new Dt("20061004T190000", true),
        new Dt("20061010T110000", true),
        new Dt("20061011T103000", true),
        new Dt("20061010T160000", true),
        new Dt("20061011T110000", true),
        new Dt("20061012T110000", true),
        new Dt("20061012T160000", true),
        new Dt("20061013T110000", true),
        new Dt("20061017T153000", true),
        new Dt("20061005T170000", true),
        new Dt("20061013T073000", true),
        new Dt("20061026T080000", true),
        new Dt("20061004T180000", true),
        new Dt("20061004T194000", true),
        new Dt("20061206T183000", false),
        new Dt("20061018T200000", true),
        new Dt("20061006T180000", true),
        new Dt("20061020T200000", true),
        new Dt("20061021T200000", true),
        new Dt("20061014T110000", true),
        new Dt("20061027T180000", true),
        new Dt("20061103T200000", false),
        new Dt("20061104T180000", false),
        new Dt("20061110T180000", false),
        new Dt("20061110T200000", false),
        new Dt("20061115T180000", false),
        new Dt("20061111T180000", false),
        new Dt("20061208T180000", false),
        new Dt("20061017T130000", true),
        new Dt("20061019T160000", true),
        new Dt("20061102T160000", false),
        new Dt("20061020T103000", true),
        new Dt("20061016T120000", true),
        new Dt("20061018T160000", true),
        new Dt("20061025T160000", true),
        new Dt("20061101T160000", false),
        new Dt("20061017T190000", true),
        new Dt("20061018T103000", true),
        new Dt("20061025T123000", true),
        new Dt("20061013T060000", true),
        new Dt("20061023T160000", true),
        new Dt("20061018T160000", true),
        new Dt("20061025T160000", true),
        new Dt("20061025T083000", true),
        new Dt("20061019T130000", true),
        new Dt("20061018T120000", true),
        new Dt("20061018T153000", true),
        new Dt("20061020T130000", true),
        new Dt("20061111T140000", false),
        new Dt("20061023T100000", true),
        new Dt("20061103T081500", false),
        new Dt("20061027T130000", true),
        new Dt("20061026T140000", true),
        new Dt("20061025T083000", true),
        new Dt("20061104T140000", false),
        new Dt("20061024T110000", true),
        new Dt("20061026T110000", true),
        new Dt("20061101T103000", false),
        new Dt("20061028T163000", true),
        new Dt("20061108T103000", false),
        new Dt("20061109T180000", false),
        new Dt("20061110T090000", false),
        new Dt("20061113T173000", false),
        new Dt("20061103T130000", false),
        new Dt("20061103T110000", false),
        new Dt("20061104T070000", false),
        new Dt("20061207T150000", false),
        new Dt("20061109T160000", false),
        new Dt("20061116T160000", false),
        new Dt("20061108T160000", false),
        new Dt("20061108T110000", false),
        new Dt("20061108T170000", false),
        new Dt("20061110T130000", false),
        new Dt("20061110T103000", false),
        new Dt("20061110T120000", false),
        new Dt("20061109T200000", false),
        new Dt("20070119T190000", false),
        new Dt("20070209T190000", false),
        new Dt("20061115T160000", false),
        new Dt("20061206T160000", false),
        new Dt("20061130T160000", false),
        new Dt("20061114T130000", false),
        new Dt("20061201T110000", false),
        new Dt("20061115T103000", false),
        new Dt("20061117T200000", false),
        new Dt("20061117T190000", false),
        new Dt("20061124T160000", false),
        new Dt("20061125T160000", false),
        new Dt("20061117T140000", false),
        new Dt("20061206T093000", false),
        new Dt("20061219T073000", false),
        new Dt("20061117T110000", false),
        new Dt("20070205T173000", false),
        new Dt("20061203T110000", false),
        new Dt("20070215T113000", false),
        new Dt("20070216T120000", false),
        new Dt("20061128T130000", false),
        new Dt("20061122T103000", false),
        new Dt("20061206T103000", false),
        new Dt("20061129T093000", false),
        new Dt("20061206T093000", false),
        new Dt("20061206T160000", false),
        new Dt("20061207T150000", false),
        new Dt("20061130T100000", false),
        new Dt("20070124T160000", false),
        new Dt("20061129T153000", false),
        new Dt("20061208T120000", false),
        new Dt("20061130T063000", false),
        new Dt("20070418T160000", true),
        new Dt("20070131T160000", false),
        new Dt("20070214T160000", false),
        new Dt("20070228T160000", false),
        new Dt("20070425T160000", true),
        new Dt("20061211T153000", false),
        new Dt("20061204T140000", false),
        new Dt("20070404T160000", true),
        new Dt("20061212T123000", false),
        new Dt("20061212T160000", false),
        new Dt("20061213T093000", false),
        new Dt("20061221T140000", false),
        new Dt("20061218T100000", false),
        new Dt("20070214T190000", false),
        new Dt("20070228T193000", false),
        new Dt("20070321T160000", true),
        new Dt("20070404T193000", true),
        new Dt("20070408T193000", true),
        new Dt("20071210T160000", false),
        new Dt("20071013T100000", true),
        new Dt("20070119T161500", false),
        new Dt("20061221T080000", false),
        new Dt("20070109T140000", false),
        new Dt("20070122T140000", false),
        new Dt("20070126T120000", false),
        new Dt("20070111T090000", false),
        new Dt("20070112T090000", false),
        new Dt("20070117T083000", false),
        new Dt("20070118T083000", false),
        new Dt("20070119T083000", false),
        new Dt("20070125T090000", false),
        new Dt("20061215T171500", false),
        new Dt("20061216T003000", false),
        new Dt("20060127T003000", false),
        new Dt("20070105T150000", false),
        new Dt("20061226T070000", false),
        new Dt("20070124T160000", false),
        new Dt("20070124T160000", false),*/
        new Dt("20070124T160000", false),
        new Dt("20070124T160000", false),
        new Dt("20070124T160000", false),
        new Dt("20070124T160000", false),



    };
  }
}
